#
# spec file for package sysconfig (Version 0.72.6)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           sysconfig
Version:        0.72.6
Release:        2.6.1
Summary:        The sysconfig scheme
Group:          System/Base
License:        GPLv2+
AutoReqProv:    on
PreReq:         %fillup_prereq %insserv_prereq textutils fileutils gawk sed grep
Requires:       iproute2 dbus-1 hal procps
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         %name-%version.tar.bz2
Patch1:         sysconfig-attr-in-convert_persistent_name_rules.bnc546575.diff
Patch2:         sysconfig-allow-ifup-lo-in-nm-flow.bnc547620.diff
Patch3:         sysconfig-no-wireless-ap-for-wl-driver.bnc555774.diff
Patch4:         sysconfig-avoid-pcmcia-prod_id-err-msg.bnc551640.diff
Patch5:         sysconfig-ifup-dhcp-running-detection.bnc562030.diff
Patch6:         sysconfig-ifup-dhcp-dhcpcd-config-sync.bnc518219.diff
Patch7:         sysconfig-ifup-tunnel-allow-existing-tap.bnc557864.diff
Patch8:         sysconfig-udevmountd-don-t-handle-crypto-devices.bnc568577.diff
Patch9:         sysconfig-same-vlan-id-on-multiple-ifaces.bnc572186.diff
Patch10:        sysconfig-ifstatus-route-skip-foreign-routes.bnc572205.diff

%description
This package provides the SuSE system configuration scheme.



Authors:
--------
    Olaf Kirch <okir@suse.de>
    Bjoern Jacke <bjoern@j3e.de>
    Mads Martin Joergensen <mmj@suse.de>
    Peter Poeml <poeml@suse.de>
    Arvin Schnell <arvin@suse.de>
    Michal Svec <msvec@suse.cz>
    Christian Zoz <zoz@suse.de>
    Werner Fink <werner@suse.de>
    Marius Tomaschewski <mt@suse.de>

%prep
%setup -n sysconfig-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1

%build
autoreconf --force --install
CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -fPIC" \
./configure --prefix=/ \
            --sbindir=/sbin \
            --libdir=/%_lib \
            --libdir=/usr/%_lib \
            --sysconfdir=%_sysconfdir \
            --mandir=%_mandir \
            --with-fillup-templatesdir=/var/adm/fillup-templates
%{__make}

%check
make check

%clean
rm -rf $RPM_BUILD_ROOT

%install
make DESTDIR=$RPM_BUILD_ROOT install
# This directory is not used since some time (was used for ifup locking)
mkdir -p $RPM_BUILD_ROOT/var/lock/subsys/sysconfig
touch $RPM_BUILD_ROOT/etc/sysconfig/network/config
touch $RPM_BUILD_ROOT/etc/sysconfig/network/dhcp
# install udevmountd
mkdir -p $RPM_BUILD_ROOT/lib/udev
mv $RPM_BUILD_ROOT/sbin/udevmountd $RPM_BUILD_ROOT/lib/udev
# remove template dir
rm -rf $RPM_BUILD_ROOT/etc/sysconfig/network/ifservices.template/

%files
%defattr(-,root,root)
/etc/init.d/*
%ghost /etc/sysconfig/network/config
%ghost /etc/sysconfig/network/dhcp
%config(noreplace) /etc/sysconfig/network/ifcfg-lo
%config(noreplace) /etc/sysconfig/network/ifroute-lo
%config(noreplace) /etc/ppp/ip-up
%config(noreplace) /etc/ppp/ip-down
%config(noreplace) /etc/ppp/ipv6-up
%config(noreplace) /etc/ppp/ipv6-down
%dir /etc/udev
%dir /etc/udev/rules.d
%config /etc/udev/rules.d/77-network.rules
%config /etc/udev/rules.d/81-mount.rules
%dir /lib/udev
/lib/udev/udevmountd
%dir /etc/modprobe.d
%config /etc/modprobe.d/50-blacklist.conf
%config(noreplace) /etc/modprobe.d/50-ipv6.conf
/etc/sysconfig/network/ifcfg.template
/etc/sysconfig/network/scripts/*
/etc/sysconfig/hardware
/etc/netconfig.d
/etc/ppp/poll.tcpip
/etc/NetworkManager
/sbin/*
%doc /usr/share/doc/packages/sysconfig
%_mandir/*/*
/usr/share/omc/svcinfo.d/network.xml
/var/adm/fillup-templates/sysconfig.dhcp-network
/var/adm/fillup-templates/sysconfig.config-network
%dir /var/lock/subsys/sysconfig

%pre
if [ -f etc/sysconfig/hardware ] ; then
    mv etc/sysconfig/hardware etc/sysconfig/ide
fi
# package update ?
if [ ${1:-0} -gt 1 ]; then
	# conversion of persistent name rules
	if [ -f /etc/udev/rules.d/30-net_persistent_names.rules ] ; then
		mv -v /etc/udev/rules.d/30-net_persistent_names.rules \
		      /etc/udev/rules.d/30-net_persistent_names.rules.to_convert
	fi
	# if oldversion < 0.70.0
	touch etc/sysconfig/network/__convert_hwdesc_to_iface__
	# fi
	# update to >= 0.72.1
	if [ ! -f etc/sysconfig/network/scripts/move_shm_sysconfig.sh ] ; then
		touch etc/sysconfig/network/__move_shm_sysconfig__
	fi
fi

%post 
# * update to >= 0.72.1: before anything else, move state
#   files from dev/shm/sysconfig to dev/.sysconfig/network
if [ -f etc/sysconfig/network/__move_shm_sysconfig__ ] ; then
	etc/sysconfig/network/scripts/move_shm_sysconfig.sh .
	rm -f etc/sysconfig/network/__move_shm_sysconfig__
fi
pushd etc/sysconfig/network >/dev/null
for i in ifcfg-ppp* ifcfg-ippp* ifcfg-dsl* ifcfg-modem* ; do
    case $i in 
	ifcfg-ippp\*|ifcfg-ppp\*|ifcfg-dsl\*|ifcfg-modem\*)
	    # drop no matching file
	    continue ;;
	*~*|*.*) 
	    # drop backup files, rpm{save,new,orig}
	    continue ;;
	ifcfg-ippp*|ifcfg-ppp*|ifcfg-dsl*|ifcfg-modem*)
	    # optfile
	    grep -q -s "^USERCONTROL" $i
	    if [ $? -ne 0 ] ; then
		echo "USERCONTROL=\"yes\"" >> $i
	    fi
	    ;;
    esac
done
popd >/dev/null
if [ -d etc/sysconfig/isdn ]; then
    pushd etc/sysconfig/isdn >/dev/null
    for i in cfg-net* ; do
	case $i in
	cfg-net\*)
	    # drop no matching file
	    continue ;;
	*~*|*.*)
	    # drop backup files, rpm{save,new,orig}
	    continue ;;
	cfg-net*)
	    PROTOCOL=""
	    proto=`grep "^PROTOCOL" $i`
	    eval $proto
	    if [ "$PROTOCOL" = "syncppp" ] ; then
		grep -q -s "^USERCONTROL" $i
		if [ $? -ne 0 ] ; then
		    echo "USERCONTROL=\"yes\"" >> $i
		fi
	    fi
	    ;;
	esac
    done
    popd >/dev/null
fi
# conversion of persistent name rules
if [ -f /etc/udev/rules.d/30-net_persistent_names.rules.to_convert ] ; then
	etc/sysconfig/network/scripts/convert_persistent_name_rules
fi
# convert hwdescs to interface names in config filenames and variables
if [ -f etc/sysconfig/network/__convert_hwdesc_to_iface__ ] ; then
	pushd etc/sysconfig/network
	scripts/hwdesc2iface netconfig .
	for cf in ifcfg-*; do
		scripts/hwdesc2iface $cf
	done
	if [ -f ../SuSEfirewall2 ] ; then
		scripts/hwdesc2iface ../SuSEfirewall2 FW_DEV_
	fi
	rm -f __convert_hwdesc_to_iface__
	popd
fi
#
pushd /etc/sysconfig/hardware > /dev/null
for cfg in hwcfg-*-ccw-* hwcfg-*-iucv-* ; do
	[ -f $cfg ] && bash ./hwcfg2rules $cfg
done
popd > /dev/null
#
## we provide own, improved variant of the remove_and_set suse
## rpm macro that is able to handle files in subdirs, and more
. etc/sysconfig/network/scripts/functions.rpm-utils
#
%{fillup_and_insserv -fY network}
%{fillup_and_insserv -fY network-remotefs}
# remove first, we need the new default value
sysconfig_remove_and_set network/dhcp DHCLIENT_TIMEOUT
%{fillup_only -dns dhcp network network}
%{fillup_only -dns config network network}
/sbin/ldconfig
echo "Removing old autogenerated device configuration files:"
rm -vf $(grep -sl "HOTPLUG-FLAG: *autocreated" /etc/sysconfig/hardware/hwcfg-*)
sysconfig_remove_and_set storage HOTPLUG_MOUNT_FSTAB HOTPLUG_CHECK_FILESYSTEMS
#
# * update to >= 11.1 / SLE11:
#
# convert dns / modify_resolvconf to netconfig
if [ -e etc/sysconfig/network/scripts/convert_to_netconfig_dns ] ; then
    ROOT=$PWD bash etc/sysconfig/network/scripts/convert_to_netconfig_dns
fi
# convert nis / dhclient variables to netconfig
if [ -e etc/sysconfig/network/scripts/convert_to_netconfig_nis ] ; then
    ROOT=$PWD bash etc/sysconfig/network/scripts/convert_to_netconfig_nis
fi
# remove ntp variables obsoleted by netconfig (new default is "yes")
# as well as some another obsolete dhcp variables
for file in etc/sysconfig/network/dhcp etc/sysconfig/network/ifcfg-* ; do
	name="${file##*\/ifcfg-}"
	case $name in
	(lo|""|*" "*|*~|*.old|*.rpmnew|*.rpmsave|*.scpmbackup) continue ;;
	esac
	sysconfig_remove_and_set -b "" $file \
		DHCLIENT_MODIFY_NTP_CONF     \
		DHCLIENT_ADDITIONAL_OPTIONS  \
		DHCLIENT_SCRIPT_EXE
done
# erroneous move from network/dhcp to network/config while 11.1 beta
sysconfig_remove_and_set network/config WRITE_HOSTNAME_TO_HOSTS
#
# * update to >= 11.2
#
# move ipv6 settings created by yast2-network before 11.2
if test -f etc/modprobe.d/ipv6 ; then
	mv -f etc/modprobe.d/ipv6 etc/modprobe.d/50-ipv6.conf
fi

%postun
%{insserv_cleanup}
/sbin/ldconfig

%preun
%{stop_on_removal network}

%changelog
* Mon Mar 15 2010 mt@suse.de
- Added route proto filter to ifstatus-route to evaluate only
  routes that may have been set by ifup-route and skip routes
  added e.g. by zebra to not to waste CPU for big zebra routing
  tables (bnc#572205). Thanks to Adrian Ban for initial patch!
* Thu Jan 21 2010 mt@suse.de
- Fixed ifup-802.1q script to correctly search for the interface
  name of a vlan id in case multiple interfaces are using same
  vlan id. Thanks to Adrian Ban for a correction! (bnc#572186)
* Fri Jan 15 2010 mt@suse.de
- Applied udevmountd udev rule patch by Ludwig Nussel: don't handle
  crypto devices, boot.crypto does that already (bnc#568577)
* Wed Dec 16 2009 mt@suse.de
- Fix to allow ifup $tap when it already exists, e.g. created by
  kvm (bnc#557864).
- Synchronized ifup-dhcp and dhcpcd configuration steps to report
  status after dhcpcd really finished all its steps (bnc#518219).
- Improved detection if a dhcp client is running, causing ifup-dhcp
  and the network script to report false failures, when the client
  forks at the moment of the check (bnc#562030 and others).
* Mon Nov 23 2009 mt@suse.de
- Avoid error message, when pcmcia device does not provide its
  vendor/name info via sysfs device/prod_id files (bnc#551640).
- Fixed to not set WIRELESS_AP at all for wl driver (bnc#555774).
- Allow ifup lo, even NetworkManager is active or it breaks the
  lo setup via /etc/init.d/boot.localnet (bnc#547620,bnc#547928).
- Fixed typo in convert_persistent_name_rules script causing to
  generate persistent name rules on update, not matching MAC
  address (bnc#546575).
* Fri Oct  9 2009 mt@suse.de
- version 0.72.6
- Fixed support of eth0.VLAN interface name schema as well as custom
  names, documented it in the ifcfg-vlan(5) manual page (bnc#534032,
  fate#305947).
* Tue Oct  6 2009 mt@suse.de
- version 0.72.5
- Applied openSUSE:Factory patches into opensuse-11.2 branch
* Fri Oct  2 2009 mt@suse.de
- Fixed to check for 'iw' utility only when it is required to set
  the wireless regulatory domain (bnc#539669).
* Fri Oct  2 2009 mt@suse.de
- Fixed typo in ifstatus causing to return bad code (bnc#542230).
- Blacklisted mISDN modules in /etc/modprobe.d/50-blacklist.conf
  (bnc#537052).
* Mon Sep 28 2009 crrodriguez@suse.de
- build with -fno-strict-aliasing
* Tue Sep 22 2009 mt@suse.de
- Fixed to just reload bind instead of try-restart in netconfig
  (bnc#541035).
* Tue Sep 15 2009 mt@suse.de
- version 0.72.4
- Added note to WIRELESS_REGULATORY_DOMAIN variable description in
  /etc/sysconfig/network/config, that it needs the new nl80211 wpa
  driver, that can be enabled using the WIRELESS_WPA_DRIVER ifcfg
  variable on a per interface basis (bnc#537708).
- Fixed typo in md-on-iscsi-automount 81-mount.rules (bnc#509495).
* Wed Sep  9 2009 mt@suse.de
- Implemented support to set the wireless regulatory domain using
  WIRELESS_REGULATORY_DOMAIN network/config variable (fate#305301).
* Thu Sep  3 2009 mt@suse.de
- Added check for hostname changes to avoid a syslog reload in
  dhcpcd-hook when it didn't changed (fate#305702,bnc#466198).
- Fixed waiting for successful connection in NetworkManager in
  the /etc/init.d/network script by removing nm-online's --exit
  option, that caused to exit immediately instead of waiting up
  to NM_ONLINE_TIMEOUT seconds, because the NetworkManager has
  been started just now and not ready yet (bnc#515629).
- Added additional dhcp client specific start options variables
  DHCPCD-, DHCLIENT- and DHCP6C_USER_OPTIONS, enabling the user
  to set custom options in special cases (bnc#524695).
* Thu Aug 13 2009 mt@suse.de
- version 0.72.3
- Updated kernel driver to wpa_supplicant driver name mappings,
  added WIRELESS_WPA_DRIVER ifcfg variable allowing the user to
  specify/override the wpa driver (bnc#477833, bnc#481380).
- Fixed redirection in ifdown-bonding, remove_bond function.
- Improved to use faster pgrep in dhcp searching functions
* Wed Aug 12 2009 mt@suse.de
- version 0.72.2
- Marked tap interfaces as supported in rcnetwork localfs flow,
  to start a bridge with tap port in localfs flow (bnc#522225).
- Fixed spec file to remove the HOTPLUG_CHECK_FILESYSTEMS and
  HOTPLUG_MOUNT_FSTAB variables from /etc/sysconfig/storage
  instead of removing of the complete file (bnc#528759).
- Disabled installation of obsolete README.storage, README.s390,
  getcfg, hwup and modify_resolvconf manual pages. Updated and
  moved README.hwcfg_and_device_initialisation to package docs.
- Disabled installation of the obsolete hwup script (bnc#483774,
  fate#306215).
* Wed Aug 12 2009 mt@suse.de
- version 0.72.1
- Fixed netconfig regex checks to work with some non-English (e.g.
  Estonian) locales and to allow spaces in lease file (bnc#488257).
- Applied fix for the obsolete hwup utility to work with ccwgroup
  (qeth,lcs,ctc) devices on s390x (bnc#483774).
- Applied patch for udev 81-mount.rules to allow md devices on
  iscsi to automount (bnc#509495).
- Fixed dhclient6 variable typos in ifup-dhcp (bnc#524691).
- Improved IFPLUGD_PRIORITY documentation in ifcfg(5) man page.
- Improved the NETCONFIG_DNS_FORWARDER documentation to list the
  valid settings in netconfig(8) man page (bnc#507979).
- Fixed scripts/extradebug to avoid huge files it created.
- Changed is_iface_available() to use interface type only
- Changed to use /dev/.sysconfig/network instead of the POSIX shm
  path /dev/shm/sysconfig, that may be a dedicated file system
  (bnc#335486).
* Tue Jun 30 2009 mt@suse.de
- Applied fastboot patch from Moblin:Factory to avoid a sleep.
* Sun Jun 14 2009 ro@suse.de
- drop (already unused) libsysfs from build
* Wed Jun 10 2009 mt@suse.de
- version 0.72.0
- Improved to use /etc/sysconfig/network/scripts/firewall hook
  link for all optional calls to the firewall script allowing
  the user to point the link to another script. SuSEfirewall2
  provides the script and the link by default (bnc#485450).
- Improved makefiles and configure script, added more tests.
* Mon May 18 2009 mt@suse.de
- Improved ifup -o hotplug to filter by interface type, updated
  77-network.rules udev rule (fate#305947).
* Wed May 13 2009 mt@suse.de
- Changed to exit in ifup when network manager is enabled/active.
- Removed obsolete nm "up" notification and NM_CONTROLLED variable.
* Thu Apr 30 2009 werner@suse.de
- Use usleep for more often
* Tue Mar 24 2009 mt@suse.de
- version 0.71.15
- Added /etc/modprobe.d/50-ipv6.conf config (noreplace install)
  with IPv6 enabled by default; added renaming of yast2-network
  created ipv6 file to 50-ipv6.conf in post-install (bnc#485947).
- Fixed overlapping messages in rcnetwork output (bnc#406887).
- Fixed ifup-wireless to not set nick by default that breaks
  several drivers (bnc#478513).
- Fixed ifup-wireless to set ap to 'off' instead to 'any' for
  the madwifi driver that does not support 'any' (bnc#402438).
- Fixed network scripts to handle dummy interfaces (bnc#436857).
- Fixed ifroute script parsing of final lines without EOL in
  ifroute files (bnc#467165).
* Mon Mar  9 2009 mmarek@suse.cz
- renamed modprobe config to /etc/modprobe.d/50-blacklist.conf
  (required by new module-init-tools).
* Thu Feb 26 2009 hare@suse.de
- ctc device has been renamed to ctcm (bnc#440570)
* Wed Feb 25 2009 mt@suse.de
- Fixed to use exact match for networkmanager generation info
  comment in the resolv.conf to avoid discarding of static dns
  setup on update (bnc#471785).
* Mon Feb 23 2009 ihno@suse.de
- Blacklist chsc_sch module (bnc#478601)
* Fri Feb 20 2009 mt@suse.de
- Fixed to use absolute /sbin/modprobe in iucv rule (bnc#440570).
* Fri Feb 20 2009 mt@suse.de
- Fixed ifup-dhcp status code in case the "-o rc" option was not
  used, causing e.g. a yast2 internet test failure (bnc#460093).
- Appended bug number and .diff suffix to patch files without.
* Thu Feb 19 2009 hare@suse.de
- Initiate conversion of iucv rules (bnc#440570)
* Fri Feb  6 2009 hare@suse.de
- Automount of iSCSI devices doesn't work (bnc#457252)
* Wed Feb  4 2009 hare@suse.de
- Fixup zfcp conversion rules (bnc#471400)
* Wed Jan 28 2009 mt@suse.de
- Fixed to use ifup-infiniband to setup ibchild type (bnc#423046).
* Tue Jan 27 2009 mt@suse.de
- Added openibd to network LSB Should-Start/Stop, so infiniband
  modules are loaded before the network script runs (bnc#469600).
* Mon Jan 26 2009 mt@suse.de
- Added additional fb modules to the blacklist (bnc#468964).
* Fri Jan 23 2009 mt@suse.de
- version 0.71.14
- Added obsolete notes to legacy documentation as getcfg.8, hwup.8
  (bnc#464832), updated netconfig diagram.
* Fri Jan 23 2009 mt@suse.de
- version 0.71.13
- Mentioned in network-remotefs init script's LSB description tag,
  that it starts NetworkManager, Wireless, PPP, ... (bnc#463439).
* Fri Jan 23 2009 mt@suse.de
- Added cyblafb module to the blacklist (bnc#466280).
* Wed Jan 21 2009 mt@suse.de
- Fixed previous patch avoiding new interface types by just
  skipping creations/deletions in ifup-tunnel (bnc#467165).
* Wed Jan 21 2009 mt@suse.de
- Fix to not handle sit0,gre0,tunl0 in ifup-tunnel (bnc#467165).
* Tue Jan 20 2009 mt@suse.de
- Fixed ifup-tunnel script to modprobe modules (bnc#467165).
- Fixed ipv6 support in ifup-route script (bnc#467165).
* Thu Jan 15 2009 mt@suse.de
- Removed TPM (Trusted Platform Module) kernel modules from
  /etc/modprobe.d/blacklist (bnc#439196)
* Wed Jan 14 2009 uli@suse.de
- hwcfg2rules: explicitly disable layer2, and do so after the
  end label to make it work (bnc #442232)
* Thu Jan  8 2009 mt@suse.de
- Map obsolete (s390) interface type overrides to eth (bnc#458412).
- Fixed ifdown-autoip to check if info file exists (bnc#463266).
* Wed Jan  7 2009 schwab@suse.de
- Fix syntax errors in network init script.
* Fri Dec 19 2008 mt@suse.de
- Fixed ifup-dhcp status to match BOOTPROTO settings (bnc#460093).
* Thu Dec 11 2008 mt@suse.de
- version 0.71.12
- Fixed ifup-dhcp to disable dhcp6 client when ipv6 support is
  disabled (complain only when explicitly requested) and avoid
  that /etc/init.d/network reports it as a failure (bnc#355786).
* Thu Dec 11 2008 hare@suse.de
- Add 'udevmountd' for automatic mounts of devices from
  /etc/fstab marked with 'nofail' (bnc#457252)
* Mon Dec  8 2008 mt@suse.de
- More fixes to conversion of ctc and iucv ifcfg files (bnc#440570)
* Thu Dec  4 2008 mt@suse.de
- Fixed conversion of interface names/files using bus a based hw
  description in hwdesc2iface script (bnc#440570, bnc#442232).
* Tue Dec  2 2008 mt@suse.de
- Changed to use DHCLIENT_TIMEOUT=0 (infinite timeout) by default,
  updated variable comment (bnc#450917, fate#302402, bnc#447237).
* Tue Dec  2 2008 mt@suse.de
- Fixed passing of ip-up script args to ip-up.d scripts (bnc#450772).
* Mon Dec  1 2008 mt@suse.de
- Fixed to enable resolv.conf for netconfig when it contains a
  NetworkManager comment and avoid resetting netcofig dns policy
  when the NETWORKMANAGER variable is set to yes (bnc#450332).
- Fixed exit codes in netcontrol_global_hooks NM hook (bnc#450155).
* Fri Nov 28 2008 lnussel@suse.de
- Fixed ppp/ip-up script to fallback to DNS servers defined in
  the provider description file (bnc#449518).
* Thu Nov 27 2008 mt@suse.de
- Added DHCLIENT_USE_LAST_LEASE (-E/--lastlease) dhcpcd option to
  dhcp config and ifup-dhcp script, addopted new DHCLIENT_TIMEOUT
  default 20 and increased WAIT_FOR_INTERFACES to 30 to allow
  dhcpcd to use the old lease in time (fate#302402, bnc#447237).
* Wed Nov 26 2008 mt@suse.de
- Fixed obsolete ntp-runtime decription in netconfig.8 (bnc#446545).
- Fixed rcnetwork remotefs virtual iface start order (bnc#447098).
* Fri Nov 14 2008 hare@suse.de
- Update hwcfg2rules script to handle hsi and iucv devices
  correctly (bnc#440570)
* Wed Nov 12 2008 mt@suse.de
- Fixed udev 77-network.rules rule to skip ifup hotplug for
  bridge interfaces (bnc#443749).
* Mon Nov 10 2008 mt@suse.de
- Removed obsolete creation of /var/run/ntp directory that breaks
  ntp; when ntp is installed the directory exists, otherwise we
  can skip any efforts to configure it (bnc#443326).
* Mon Nov 10 2008 mt@suse.de
- Fix to handle multiple bonding slaves correctly (bnc#429858).
* Fri Nov  7 2008 mt@suse.de
- version 0.71.11
- Fixed to avoid stopping dhcp client when dhcp+autoip is used and
  disabled autoip usage in dhcpcd even not configured (bnc#441492).
- Changed dns to netconfig conversion to import settings without
  to restore of modify_resolvconf backup, since it may break DNS
  in a running system (bnc#434575).
* Thu Nov  6 2008 mt@suse.de
- version 0.71.10
- Implemented converting of NIS related dhcp client variables into
  netconfig variables inclusive ifcfg files (bnc#439870).
- Improved DNS conversion script to handle ifcfg files (bnc#434575).
- Fixed more issues with setting NIS domainname (bnc#437725).
- Updated netconfig documentation and variable comments.
* Wed Nov  5 2008 mt@suse.de
- Fix for rcnetwork reload problems to consider new ifcfg files
  in ifprobe and report them as not up-to-date (bnc#438776).
* Thu Oct 30 2008 mt@suse.de
- Added check to network init scripts to check if started by yast
  (YAST_IS_RUNNING) and don't enable boot or localfs mode in this
  case (bnc#439915).
* Mon Oct 27 2008 mt@suse.de
- version 0.71.9
- Fixed to fallback to the static (yast2) settings in netconfig+NM
  auto policy when NetworkManager does not provide any (bnc#434575).
- Fixes to set the NIS domainname correctly (bnc#437725).
- Fixed typo in netconfig.8 manual page (bnc#438647), updated it.
- Implemented DNS / modify_resolvconf to netconfig and dhcp client
  NIS update hooks, cleaned up variables (bnc#434575, bnc#437725).
- Fixed erroneous move of yast2-network WRITE_HOSTNAME_TO_HOSTS
  variable from network/dhcp to network/config while 11.1 beta.
- Removed commented out/obsolete rc.config related update hooks.
* Tue Oct 21 2008 mt@suse.de
- Fixed changes file to use bnc#433780 instead of bnc#428978
* Mon Oct 20 2008 mt@suse.de
- Fixed netconfig module error printing bug added while fixing of
  bug 435865 (bnc#436488).
- Allow nm to modify its settings also while NETWORKMANAGER!=yes;
  happens e.g. during network restart after the config changed.
* Thu Oct 16 2008 mt@suse.de
- Fixed to not to execute ifdown-route noiface and ifdown-dhcp all
  during a network-remotefs stop run and improved previous fix to
  skip ifup lo (bnc#433987).
* Thu Oct 16 2008 werner@suse.de
- Fix some syntax issues, should fix startup problem in bnc#433987
* Thu Oct 16 2008 mt@suse.de
- Fixed netconfig_kv_filter regex braking dhcpcd,... (bnc#435865).
- Fixed netconfig createtime handling in networkmanager=no case
  (introduced by fix for bnc#428978).
* Mon Oct 13 2008 mt@suse.de
- version 0.71.8
- Fixed netconfig argument and modify action input parsing to
  reject formated invalid input / values (bnc#433780).
- Fixed ppp/ip-up script to handle ipv6-up/down and trigger an
  firewall reconfiguration; added ipv6 links to rpm file list.
  Thanks to Ludwig Nussel (bnc#426303).
- Fixed rpm requires adding procps (/bin/ps used to find dhcpc).
* Mon Oct  6 2008 mt@suse.de
- Fixed hwdesc2iface to convert or disard only known getcfg hw
  descriptions to not to break e.g. SuSEfirewall2 (bnc#428978).
* Thu Oct  2 2008 mt@suse.de
- Changed to use udevadm settle instead of udevsettle
* Mon Sep 29 2008 mt@suse.de
- version 0.71.7
* Mon Sep 29 2008 mt@suse.de
- Set explicit permisions for netconfig generated files instead
  of prereserveing [wrong] permissions from original (bnc#428458).
- Improved netconfig check_md5_and_move function to match special
  comments additionally to the data to improve detection of user
  modifications, added matching comments to configuration hints
  and renamed it to netconfig_check_md5_and_move (bnc#428201).
- Removed incorrect check for empty dns search list skipping the
  generation of the /etc/resolv.conf file (bnc#429132).
* Thu Sep 25 2008 mt@suse.de
- Fixed netconfig scripts to avoid seq usage (bnc#285472).
- Set umask explicitly to 0022 in netconfig to avoid that e.g.
  /etc/resolv.conf gets created with unusual permissions, when
  it didn't existed before.
* Thu Sep 25 2008 mt@suse.de
- version 0.71.6
- Fixed /etc/init.d/network script to exit in localfs flow when
  the networkmanager is active (bnc#425502, bnc#285472).
- Avoid rpmlint warnings about missed lsb reload action in the
  /etc/init.d/network-remotefs script (bnc#425502).
* Wed Sep 24 2008 mt@suse.de
- Removed test hack from supported_on_localfs function...
* Tue Sep 23 2008 mt@suse.de
- version 0.71.5
- Fixed ifup-dhcp to retain spaces DHCLIENT_VENDOR_CLASS_ID and
  other dhcpcd option values (bnc#424356).
- Fixed typo and improved vlan handling in is_iface_available.
- Splitted ib interface type into ib and ibchild (e.g. ib0.8001),
  added ib vs. ibchild handling to several functions and the
  /etc/init.d/network script (bnc#423046).
- Implemented a supported_on_localfs function returning whether an
  interface is supported without a mounted remotefs (/usr on NFS)
  and extended the resolve_iface_startorder function to support an
  optional filter function (e.g. supported_on_localfs).
  Changed LSB tags in /etc/init.d/network script to not to require
  haldaemon and added localfs|remotefs filter parameter allowing to
  split the interface handling. While boot, only localfs interfaces
  are started now. Added network-remotefs script with separate LSB
  tags to start the remotefs depending interfaces later (bnc#425502).
- Corrected netconfig configuration hint comments that are written
  to the destination files like /etc/resolv.conf (bnc#428201).
* Fri Sep 12 2008 mt@suse.de
- new version 0.71.4
- Improved ifdown-dhcp script and some dhcp related functions.
- Fixed to allow to disable netconfig modules using -module in
  NETCONFIG_MODULES_ORDER variable; updated documentation.
- Fixed to follow a /etc/resolv.conf symlink to support a read
  only root-fs in netconfig modules; needs (/bin/)readline.
- Implemented netconfig.d/dns-dnsmasq module (bnc#401648).
- Fixed duplicate matching in netconfig.d/nis (bnc#423177).
- Fixed DHCLIENT_SET_HOSTNAME handling for dhcpcd (bnc#418168).
* Tue Aug 26 2008 mt@suse.de
- new version 0.71.3
- netconfig input format cleanup
* Sun Aug 24 2008 ro@suse.de
- initscript: copy *-Start to *-Stop to fix build
* Thu Aug 21 2008 mt@suse.de
- new version 0.71.2
- Implemented dhcpv6 support using dhcp6c client, improved the
  dhclient[v4] support to support multiple interfaces, replaced
  modify_resolvconf by modular netconfig scripts (fate#303618).
- Moved bondind code into a separate ifup-bonding script
- Created new ifup-infiniband script to handle ib options and
  create/delete ib child interfaces. Thanks to Moni Shoua for
  his original implementation, suggestions, tests!
- Cleaned up IPADDR PREFIXLEN NETMASK usage order in ifup
* Wed Aug  6 2008 mt@suse.de
- Added recursive resolving of virtual interface start order;
  also breaking rcnetwork reload in some cases (bnc#403968).
* Thu Jul 24 2008 mt@suse.de
- new version 0.71.1
- Improved ifcfg-tunnel.5 manual page, added tun/tap examples,
  changed TUNNEL_SET_PERSISTENT default to 'yes'; non-persistent
  tunnels are not supported yet (fate#302184).
* Mon Jul 21 2008 hare@suse.de
- Update hwcfg2rules script to cover all S/390 devices
  (fate#304939)
- Fix RPM build errors
* Mon Jul 14 2008 mt@suse.de
- Fixed typo in ethtool retcode check in ifup (bnc#405434).
* Wed Jun 25 2008 mt@suse.de
- Removed sentence about writing of udev rules (bnc#399224),
  added info about module options in /etc/modprobe.conf.local
- Added check if the dhcpcd client is still running in the
  DHCLIENT_WAIT_AT_BOOT wait loop.
- Added fix adding -p dhcpcd option to avoid deconfiguration
  of the interface at startup in nfsroot case (bnc#397484)
- Fixed typo in ifup-tunnel while applying TUNNEL_SET_GROUP
* Thu May 29 2008 mt@suse.de
- new version 0.71.0
- Moved static ip tunnel support to scripts/ifup-tunnel, added
  basic tun/tap support, updated ifcfg-tunnel(5) manual page.
- Fixes to avoid usage of utilities from /usr, because /usr may
  be mounted via nfs (bnc#285472).
* Fri May 23 2008 mt@suse.de
- new version 0.70.8
- Improved ifup-bridge script reliability and allow that the
  bridge exists, e.g. because created by xen (bnc#378595).
- Increased DHCLIENT_WAIT_AT_BOOT to 15 and added comment note,
  that RFC 2131 specifies, that the dhcp client should wait a
  random time between one and ten seconds to desynchronize the
  use of DHCP at startup (bnc#390676).
- Fixed rcnetwork reload to delete [vlan] interfaces when the
  ifcfg file got deleted and honor the -o skip option for the
  non-physical interfaces (bnc#346566).
* Wed May 14 2008 mt@suse.de
- new version 0.70.7
- Removed obsolete NetworkManagerDispatcher and DHCP DBUS Daemon
  handling from /etc/init.d/network script and the NM_DISPATCHER
  variable from network/config (bnc#389156).
- Updated ntp runtime documentation of DHCLIENT_MODIFY_NTP_CONF
  variable in network/config to /var/run/ntp/servers[.$INTERFACE].
- Updated persistent interface names documentation in the ifup.8
  manual page and replaced obsolete hwdesc parameter name and
  descriptions with interface in usage messages (bnc#372058).
- Replaced obsolete TUNNEL_LOCAL_INTERFACE with new TUNNEL_DEVICE
  variable in the ifcfg-tunnel.5 manual page (bnc#384073).
- Fixed typos in ifcfg.5 and routes.5 manual pages (bnc#384071,
  bnc#384077).
* Fri Apr 18 2008 mt@suse.de
- new version 0.70.6
- Adopted for dhcpcd 3.x update (not option compatible to 1.x)
- Adopted DHCLIENT_MODIFY_NTP_CONF documentation to new runtime ntp
  configuration feature and lease time cache directory creation in
  ifup-dhcp script (fate#303602).
- Added 127.0.0.2/8 to loopback interface to avoid problems with
  programs that check ip addresses on all interfaces, e.g. ntp.
  The 127.0.0.2 address is assigned to the hostname in /etc/hosts
  to keep the hostname usable, even when there is no another
  interface set up yet (bnc#355608).
- Added patch to remove IP/PREFIXLEN set while "ip link set up" by
  the kernel from loopback before it gets applied inclusive of a
  broadcast address as defined in the ifcfg-lo file (bug #357021).
- Corrected ifup-wireless fix (see bnc#329280) to set the wireless
  access point address to 'any' in Managed and Ad-Hoc modes only,
  to not to break Master configurations and documented this behavior
  in ifcfg.template file (bnc#379586).
- Added a guard in ifup-802.1q to avoid false errors in case the
  vlan interface already exists while rcnetwork reload.
- Fixed bonding interface down trigger to trigger down slaves first
  when bonding interface goes down. Changed the /etc/init.d/network
  script to stop bonding after physical interfaces and avoid to stop
  interfaces twice (fate#303388).
- Improved NM_CONTROLLED and ETHTOOL_OPTIONS variable description
  in ifcfg.template and NM_CONTROLLED.
- Improved network script to ignore ifcfg files with well known
  backup extensions (#340891).
* Tue Apr  1 2008 mkoenig@suse.de
- remove dir /usr/share/omc/svcinfo.d as it is provided now
  by filesystem
* Tue Jan 29 2008 mt@suse.de
- new version 0.70.5
- minor rpmlint related fixes, recoded changes file to utf8.
- spell check of manual pages and README files (Bug 349746).
- rcnetwork: Fixed interface start order to support tunnel on top
  of vlan interfaces by adding a separate vlan interface set (Bug
  [#305333], #343844).
- rcnetwork: Fixed to add only non-virtual slave interfaces to the
  mandatory interface set (MANDATORY_DEVICES) and wait for them at
  boot time (Bug #354471).
* Thu Jan 17 2008 zoz@suse.de
- Added README.hwcfg_and_device_initialisation (Bug 2996529)
- rcnetwork stop now calls ifdown on all interfaces even if service
  network was not active. This may be necessary at installation time.
  (Bug 291641)
- ifup-dhcp now also returns 'dhcp not finished' in case of dhclient
  (if it did not get a lease before ifup-dhcp terminates) (Bug 334659)
* Fri Dec 21 2007 mt@suse.de
- new version 0.70.4
- Adopted to search for vconfig and ethtool in /sbin as they got
  moved there as a prerequire of /usr on NFS fixes (bug #285472).
- Fix for arp_ip_target bonding driver option support (bug #306638).
- Improved interface stop order in rcnetwork (bug #305333, #343844)
  to avoid a permission denied while attempt to remove bond iface
  because a bridge is using it.
* Thu Dec 20 2007 jg@suse.de
- ifup-wireless: set access point address (bug #229757)
* Wed Dec 19 2007 mt@suse.de
- rcnetwork: Improved start order of interfaces to support for vlans
  on a bonding interface (bug #343844) and the use of all interface
  types in bridges.
* Fri Dec 14 2007 mt@suse.de
- new version 0.70.3, includes patch for bug #231042 from STABLE.
- ifup: changed to test if /proc/sys/net/ipv6 exists instead of the
  wrong use call "sysctl net.ipv6" aborting on 11.0 (bug #347322).
- Merged sysconfig package changelog in build system and svn
* Fri Dec 14 2007 zoz@suse.de
- netcontrol_services: fixed parsing output of iwconfig (bug #152071)
* Wed Dec 12 2007 mt@suse.de
- Applied fix by Stefan Seyfried to use uptime in the wait for
  interfaces loop instead of date that may change (bug #346559).
* Tue Dec 11 2007 mt@suse.de
- Applied dhcpcd-hook patch by Peter Varkoly fixing to log the
  concerned interface name instead of $INTERFACE (bug #305592).
* Wed Nov 28 2007 werner@suse.de
- Some small changes on pool.tcpip to reduce conflicts with already
  running fetchmail deamon or MTA (bug #231042).
* Mon Sep 17 2007 zoz@suse.de
- new version 0.70.2
- When converting interface configuration files at update look first
  in the persistent iface names udev rule file. Look in sysfs only
  if the first lookup failed. (Bug 293052)
- When updating also convert hardware descriptions in SuSEfirewall2
  sysconfig file into interface names (Bug 307210)
- poll.tcpip: accept also upper case portnames (Bug 300980)
* Tue Sep  4 2007 zoz@suse.de
- new Version 0.70.1
- Don't call 'ip' if there is no interface, because it would trigger
  automatic module loading. (Bug 199456)
* Fri Aug 10 2007 hare@suse.de
- Convert old s390 hwcfg files to udev rules
* Mon Jul 30 2007 zoz@suse.de
- new version 0.70.0
- removed /sbin/getcfg (read README.no_more_hardwaredescriptions)
- enhanced conversion of old configuration names into interface names
  + do conversion in %%post and not in rcnetwork
  + skip wlan helper files
  + fixed quoting bug in sed command
  + added variable conversion in ifcfg-* files (bridge ports and such)
- don't perform update conversion from pre-9.1 (needs fixes)
- remove superfluous script 'check_configurations'
- functions: remove getcfg from get_ifplugd_priority() and comments
- netcontrol_global_hooks: remove getcfg
- ifup: dbus-send is now in /bin
* Thu Jul 26 2007 zoz@suse.de
- new version 0.69.5
- removed /lib/udev/trigger_firmware_loading.sh; lets see if we still
  need that hack. If yes it will go also to udev package.
- added script that creates an example ifservices directory
- fixed bonding setup
  + use sysfs instead of ifenslave
  + remove slaves before removing master
- ifup-wireless: always exit if iface is not wireless
- functions: added get_iface_type() and get_iface_type_from_config()
  These functions determine the type of interfaces independent of
  the interface name.
- ifup + rcnetwork: use new get_iface_type* functions
- ifup-bridge:
  + replaced wrong output command
  + wait until bridge is in forwarding state and don't recommend
    increasing DHCLIENT_WAIT_AT_BOOT anymore (Bug 193216)
- hwup* + hwcfg: Device initialisation is now done completely in
  udev rules. hwcfg-* config files will no longer be used. Since
  old hwcfg-* config files mostly contain default setting, they will
  not be converted in something else.
  + replaced hwup with a small script that can dis/en-able devices
    with sysfs means (unbind + event trigger)
  + removed all hwup helper scripts and config skeletons
* Mon Jul 16 2007 zoz@suse.de
- removed /lib/udev/mount.sh and corresponding udev rule. There will
  be a improved rule in udev package instead.
* Thu Jul 12 2007 zoz@suse.de
- Removed snd* modules from blacklist (Bug 291252)
- modify_resolvconf: make reading resolv.conf more robust (Bug 285462)
* Mon Jul  9 2007 zoz@suse.de
- new version 0.69.0
- removed getcfg from rcnetwork, ifup and ifup-helper.
- automatically convert old configuration names into ifcfg-<interface>
  (currently in rcnetwork since YaST is not up to date)
* Fri Jul  6 2007 zoz@suse.de
- new version 0.61.1
- Clean up regarding interface renaming:
  + removed PERSISTENT_NAME from scripts, config files and doc
  + fixed handling of "renamed" flag
  + removed outdated README.Persistent_Interface_Names
- Device initialisation is now done in udev rules directly and hwup
  is no longer called from udev. Removed 80-sysconfig.rules.
* Fri Jun 22 2007 zoz@suse.de
- ifup-route: make reading file 'routes' more robust (Bug 285125)
- ifup-dhcp:
  + don't take down other interfaces when setting up one (Bug 282033)
  + improve fix for not taking down to much interfaces (Bug 260073)
- cleanup of dhcp functions:
  + moved functions from ifup-dhcp to functions
  + made dhcp-interfaces a function and removed the file
  + eliminate my_pidof and my_readlink
- moved sysconfig variables in sysconfig editor from
  network/hardware/config to network/general (Bug 278612)
- fixed typo in ifup-bridge (Bug 282668)
- SuSEfirewall2: (both Bug 283744)
  + don't start it from ifup; Sfw2 now installs script in if-up/
  + avoid multiple Sfw2 runs at network restart
* Thu Jun 21 2007 adrian@suse.de
- fix changelog entry order
* Thu Jun 21 2007 coolo@suse.de
- avoid running SuSEfirewall in boot.localnet
* Mon Jun 18 2007 coolo@suse.de
- Only start network after firewall was setup
* Sun May  6 2007 zoz@suse.de
- new version 0.61.0
- remove rename_netiface. Will be replaced by write_net_rules from
  udev package.
- removed 30-net_persistent_names.rules and moved 31-network.rules
  to 77-network.rules
- added network name rules conversion script and call it in %%post
* Tue Apr 24 2007 zoz@suse.de
- ifstatus: don't write to syslog by default. Use option 'syslog'
  if you want ifstatus write to syslog. (Bug 261350)
- ifdown-dhcp: don't take down to much interfaces (Bug 260073)
* Thu Mar 29 2007 jg@suse.de
- new version 0.60.7
- ifup-wireless: do not insist on having wlanctl-ng installed
  (bug 257788)
* Mon Mar 12 2007 zoz@suse.de
- Only use first interface when looking for interface name based
  configuration names of infiniband interfaces (ib*) (Bug 204098)
* Sat Mar 10 2007 dmueller@suse.de
- support rt2500* class of drivers for WPA
* Mon Feb 19 2007 zoz@suse.de
- Don't quit if device seems already to be bound to a driver, because
  sometimes we check the wrong device. (Bug 232279)
* Fri Feb 16 2007 jg@suse.de
- ifcfg.template: removed duplicate WIRELESS_WPA_PROTO variable
* Sat Feb  3 2007 zoz@suse.de
- fixed comment of sysconfig variable MODIFY_RESOLV_CONF_DYNAMICALLY
* Tue Jan 30 2007 zoz@suse.de
- hwup: strip "static-" from hwdesc if needed (Bug 179604)
* Fri Jan 19 2007 werner@suse.de
- poll-tcpip: Add support for uucp over ssh tunnel for dynamic IPs
* Thu Jan 18 2007 zoz@suse.de
- Fixed wrong comment in rename_netiface
- Fixed quoting of variables *DRIVER* since driver names unfortunately
  may contain spaces. (Bug 234532)
* Fri Jan 12 2007 zoz@suse.de
- new version 0.60.6
- Added OMC service Description Document (Fate 301838)
* Wed Dec 20 2006 poeml@suse.de
- /etc/sysconfig/hardware/hwcfg-static-0 files do not longer need
  to be created [#114088]
* Tue Dec 12 2006 zoz@suse.de
- Don't create persistent name udev rules for hostapd interfaces.
  (Bug 214962)
- Don't deal with wlan helper interfaces (wifi*) of type 801.
  (Bug 222529)
* Sun Dec 10 2006 zoz@suse.de
- new version 0.60.5
- ifup-dhcp: To make 'ifup-dhcp status' deal with infinite leases as
  handed out by BOOTP servers or misconfigured DHCP servers, we also
  check that case for 'status'. (Bug 192745)
  See changes for 'stop' at Mon Jan 26 18:21:09 CET 2004
- Fixed handling of 'ficon' interfaces. (Bug 181998)
- rename_netiface: Don't be confused by two digit interface numbers
  (eth1 was renamed if eth1* existed) (Bug 204964)
* Mon Nov 20 2006 zoz@suse.de
- new version 0.60.4
- Removed replacements for pidof, checkproc, killproc again (See
  changes from Wed Oct  4). Instead added improved my_pidof which is
  only used for ifup-dhcp and dhcp-interfaces (Bug 213249, 55370)
* Mon Nov 13 2006 schwab@suse.de
- Fix syntax error in 80-sysconfig.rules.
* Fri Nov 10 2006 zoz@suse.de
- Added OSS module opl3sa2 to blacklist (Bug 219758)
* Thu Nov  9 2006 jg@suse.de
- trigger firmware hack: check for lower 24 bits of the MAC address
  being zero only, so the hack works for unpatched prism54 driver
  as well
* Wed Nov  8 2006 kukuk@suse.de
- Remove again unused build requires
* Mon Nov  6 2006 zoz@suse.de
- new version 0.60.3
- hwup and 80-sysconfig.rules: added 'platform' to the list of
  handled subsystems (Bug 214653)
- added new sysconfig variable WRITE_HOSTNAME_TO_HOSTS to 'dhcp'
  in /etc/sysconfig/network. This variable is only used from YaST
  (Bug 207392)
* Thu Nov  2 2006 zoz@suse.de
- udev.rules: added dsl* to the list of interface names for which we
  don't call ifup/down (Bug 211936)
- rcnetwork: removed message about NM_ONLINE_TIMEOUT (Bug 203693)
* Tue Oct 31 2006 zoz@suse.de
- new version 0.60.2
- rcnetwork: consider also bridge ports as mandatory interfaces and
    wait for them (Bug 193216)
- ifcfg-bridge.5: Recommend increasing DHCLIENT_WAIT_AT_BOOT if
    BOOTPROTO=dhcp (Bug 193216)
- bonding:
  + don't initialize bonding interface a second time (which results
    in wrong error messages) when dhcp client calls ifup for POST_UP
    stuff. (Bug 190093)
  + set interface options twice, because some must be set before and
    some after enslaving devices. (Bug 190377)
* Fri Oct 27 2006 jg@suse.de
- new version 0.60.1
- ifup-wireless: using wext driver back-end for madwifi now
* Tue Oct 24 2006 zoz@suse.de
- Avoid unneccessary output from sysctl in ifup (Bug 201658)
- blacklist 82875p_edac. (Bug 213840)
- added hal and dbus to 'Requires:' in specfile since rcnetwork
  requires these services. (Bug 214652)
* Sat Oct 21 2006 thoenig@suse.de
- Let the checkproc replacement be LSB compliant (b.n.c #213249).
* Mon Oct  9 2006 kay.sievers@suse.de
- new version 0.60.0
- use sysfs "subsystem" link instead of deprecated "bus" link
* Wed Oct  4 2006 zoz@suse.de
- Don't kill ipw3945d at interface remove event (Bug 203688)
- Don't restrict ETHTOOL_OPTIONS to arguments of '-s'. Also allow
  other options like '-K iface rx on'. (Bug 199682)
- Add replacements for pidof, checkproc, killproc written in shell
  code, which do not stat executables in /proc/*/*, to prevent
  hangs with disappeared NFS mounts [#55370] [#187175]
* Mon Sep 11 2006 seife@suse.de
- fix libsysfs2 port
* Thu Aug 31 2006 kay.sievers@suse.de
- use libsysfs2 interface
* Thu Aug 17 2006 kukuk@suse.de
- Remove undocumented ifservices.template directory to break down
  build dependencies.
* Mon Jun 26 2006 schwab@suse.de
- Handle aoa-soundbus subsystem.
* Fri Jun  2 2006 zoz@suse.de
- Changed comment for LOAD_UNSUPPORTED_MODULES_AUTOMATICALLY; now
  also rcacpid respects this setting (Bug 180654)
- Set LOAD_UNSUPPORTED_MODULES_AUTOMATICALLY=yes only for SLES and
  not for SLED (Bug 162970)
- 'ifdown-dhcp all' kills dhcp clients with -9, because interfaces
  with STARTMODE=nfsroot must stay up and running. (Bug 176804)
- ifdown calls ifdown-dhcp even if BOOTPROTO=static. We need this to
  to stop dhcp client after reconfiguration to static ip address
  via YaST (which calls rcnetwork reload). (Bug 179895)
- eliminated two error messages that occur when interface bonding
  is activated. (Bug 181129)
* Tue May 30 2006 zoz@suse.de
- Don't load module 'bonding' multiple times but create and delete
  bonding interfaces via sysfs attribute. (Bug 157936)
* Mon May 22 2006 poeml@suse.de
- fix dhcpcd-hook so that syslog picks up a changed hostname during
  bootup, by reloading syslog. The reload was already being done
  during IP address change ("renew state") but not during "up"
  state. (Bug 160916)
* Thu May 18 2006 zoz@suse.de
- rcnetwork: quoted two occurrences $OLDPWD to allow spaces in
  directory names. (Bug 174029)
- added sysconfig variable NM_ONLINE_TIMEOUT. If not set to 0, then
  rcnetwork will wait at least this time until a network connection
  has established. (Bug 169632)
- start NMdispatcher before and stop it after NM itself (Bug 169632)
* Tue May  9 2006 poeml@suse.de
- fixed a debug message in update script. Show the right sysfs path.
* Fri Apr 28 2006 jg@suse.de
- using wrapper script to kill ipw3945d (Bug 170099)
* Thu Apr 13 2006 zoz@suse.de
- rcnetwork reload now restarts NetworkManager (Bug 162959)
* Wed Apr  5 2006 jg@suse.de
- ifcfg.template: documented WIRELESS_WPA_PROTO, WIRELESS_EAP_AUTH,
  and WIRELESS_PEAP_VERSION
- ifcfg.template: fixed two typos
* Thu Mar 30 2006 zoz@suse.de
- rename_netiface: don't rename vlan interfaces (Bug 160317)
* Mon Mar 27 2006 jg@suse.de
- ifup-wireless: do not set default anonymous_identity as it may
  break WPA-EAP TLS connection
- ifup-wireless: always use iwconfig for zd1211 driven interfaces
  (bug 157503, second try)
* Sun Mar 26 2006 zoz@suse.de
- new version 0.50.9
- restricted udev rule for ifup/down: should not be called for
  ppp*|ippp*|isdn*|plip*|lo*|irda*|dummy*|ipsec*|tun*|tap*|bond*|vlan*|modem*
  (Bug 157936)
* Wed Mar 22 2006 jg@suse.de
- ifup-wireless: always use iwconfig for zd1211 driven interfaces
  (bug 157503)
* Mon Mar 20 2006 zoz@suse.de
- new version 0.50.8
- Fixed udev rule which stops ipw3945d (Bug 159062)
- hwup now always binds devices that were unbound by hwdown (Bug 159110)
- start ipw3945d after binding a device to driver ipw3945 (Bug 159062)
- update hwup.8
- added interface names ctc* and tr* to the list of handled interfaces
  in rename_netiface (Bug 153712)
* Fri Mar 17 2006 zoz@suse.de
- new version 0.50.7
- getcfg: added interfacetype 'osn' to the interface compatibility
  lists. (Bug 158654)
- removed getcfg-make-hwdesc and getcfg-device, because they never
  worked (properly) (Bug 159008)
- rcnetwork: If NM is used start/stop also dhcdbd (Bug 159125)
* Mon Mar 13 2006 zoz@suse.de
- hwup: before trying to load a module finally check both if module
  is lodaded (or compiled in) or if device is attached to the
  driver. (Again bug 154383)
* Mon Mar 13 2006 zoz@suse.de
- rename_netiface:
  + rule creation might have failed in some cases (Bug 157528)
  + added support for qeth and hsi interfaces on S390 (Bug 153712)
* Sat Mar 11 2006 zoz@suse.de
- hwdown: Also respect DRIVER==skip when releasing devices (Bug 157412)
* Sat Mar 11 2006 zoz@suse.de
- hwup should not unbind grouped devices (on s390). Therefore we now
  skip (un)binding devices for busname 'ccw'. (Bug 157412)
- getcfg does again find configurations for (still) not existing interfaces.
  If failed to do so since fix for bug 152499 (Bug 157081)
* Fri Mar 10 2006 zoz@suse.de
- new version: 0.50.6
- getcfg:
  + fixed another segfault (Bug 156940)
    (getcfg failed if a config file ends with '-')
  + fixed endless loop which occured with '-vvv' (Bug 156942)
- /etc/sysconfig/hardware/config:DRIVER must be empty by default.
  (Bug 157063)
- hwup now really checks presence of a module instead the driver link
  of the device (Improvement of change from Wed Mar 1 16:55:04 CET 2006)
  (Bug 154383)
* Fri Mar 10 2006 jg@suse.de
- ifup-wireless: changed ap_scan default for ipw2100 and
  ndiswrapper (using ap_scan=2 is a bad idea when proto and
  ciphers are unset, bug 128496)
- added variables WIRELESS_WPA_PROTO, WIRELESS_CIPHER_PAIRWISE,
  and WIRELESS_CIPHER_GROUP to allow correct use of
  WIRELESS_AP_SCANMODE=2 (bugs 152291 and 128496)
* Fri Mar 10 2006 jg@suse.de
- renamed 31-net_create_names.rules to 31-network.rules and added
  two rules
  + start ipw3945d after ipw3945 was loaded (driver event)
  + terminate ipw3945d on interface removal event
- also moved rules for ifup/down to 31-network.rules
* Thu Mar  9 2006 zoz@suse.de
- fixed another segfault in getcfg (Bug 154727)
  ('getcfg lo' failed in s390)
* Wed Mar  8 2006 hare@suse.de
- getcfg fails for grouped devices on S/390.
* Thu Mar  2 2006 zoz@suse.de
- ifup no longer checks for /sbin/ifplugd if STARTMODE!=ifplugd (Bug 154699)
* Wed Mar  1 2006 zoz@suse.de
- Teach hwup to be happy if a wanted module is already loaded or
  built in the kernel. (Bug 154383)
- Add bus type 'vio' to list of valid busses in getcfg. (Bug 154289)
- Skip loading bttv for certain devices without subids (Bug 149588)
* Tue Feb 28 2006 zoz@suse.de
- ifup: execute post up scripts if called with '-o dhcp' (Bug 154126)
* Mon Feb 27 2006 jg@suse.de
- ifup-wireless: prevent ipw3945 from being setup up as wlan-ng
  interface
- ifup-wireless: allow wpa_supplicant for ipw3945 devices
* Tue Feb 21 2006 zoz@suse.de
- Fix determination of essid in netcontrol_services (Bug 152071)
- sysconfig.spec: moved rm -Rf $BUILDROOT to %%clean
- Added module stradis to blacklist (Bug 144623)
- getcfg:
  + again checks for interface id also if there is no devicepath.
    e.g. no device link for an interface. (Bug 152499)
  + fixed segmentation fault, introduced by fix for bug 145778
    (prefix 'static-' should be ignored)
  + fixed another segfault fault which became visible by bugfix 152499
- STARTMODE=ifplugd: ifup/down will now always start/stop ifplugd if not
  called with -o ifplug (which is used by ifplugd-selectif). (Bug 152824)
* Mon Feb 20 2006 schwab@suse.de
- Fix modification of sysconfig.config-hardware in .spec.
* Mon Feb 20 2006 zoz@suse.de
- new version 0.50.5
- added sysconfig variable LOAD_UNSUPPORTED_MODULES_AUTOMATICALLY.
  Default will be 'no' in SLES and 'yes' else (Bug 148091)
- hwup does not try to bind a device to a driver if
  - there is no busname
  - DRIVER=skip
  The latter can be set globally if manual binding makes trouble.
- hwup: removed all occurencies of variables BUS{NAME,ID} because
  there already is HWD_BUS{NAME,ID}.
* Fri Feb 17 2006 hare@suse.de
- hwup: Fixed iucv initialisation (#145778)
* Thu Feb 16 2006 hare@suse.de
- hwup-{ccw,zfcp,iucv,ctc}: Porting fixes from SLES9
  (#151192 - LTC21703).
* Wed Feb 15 2006 jg@suse.de
- ifup-wireless: changed wpa_supplicant backend to 'wext' for
  ndiswrapper
- ifup-wireless: using AP scanmode 2 by default for ndiswrapper
* Tue Feb 14 2006 zoz@suse.de
- functions.common: create directory RUN_FILES_BASE (currently
  /dev/shm/sysconfig) if it does not exist (Bug 150828)
- additional fixes of returnvalues for ifplugd (Bug 140124)
- add debug helper script 'extradebug' and let normal messages be
  printed to stdout.
* Tue Feb 14 2006 jg@suse.de
- ifup-wireless: fixed authmode setting for madwifi (used with
  shared key authentication)
* Mon Feb 13 2006 zoz@suse.de
- Let ifup store the last used configuration name for an interface
  to make switch to an alternative interface via ifplugd possible
  if the interface is removed. (Bug 150308)
- Reworked fix for bug 134899 (changes from Fri Nov 25 10:56:31)
  ifup-dhcp does now check if ifup is active on this interface.
- Fixed returnvalue of ifstatus for certain states. Now rcnetwork
  can better decide if to wait for interfaces configured with
  STARTMODE=ifplugd. (Bug 140124)
- Added template for ifservices-* directory
- Added variable MODIFY_RESOLV_CONF_STATIC_DNS (Bug 136844)
- modify_resolvconf does now change /etc/named.d/forwarders.conf
  instead of /etc/named.conf (Bug 134692)
- add STARTMODE 'nfsroot' (Bug 150507)
* Tue Feb  7 2006 zoz@suse.de
- check if NetworkManagerDispatcher is installed before checking if
  it is running. (Bug 148054)
* Mon Feb  6 2006 seife@suse.de
- fix invalid blacklist entries
* Mon Feb  6 2006 zoz@suse.de
- new version 0.50.3
- getcfg: fixed getting network configurations named type-*
- Don't consider configurations type-* as mandatory devices
- Better determination of primary dhcp interfaces (Bug 136239)
* Mon Feb  6 2006 jg@suse.de
- config/31-net_create_names.rules: removed wlanconfig call to
  auto-create station interface for Atheros devices (driver does
  it itself now)
* Tue Jan 31 2006 zoz@suse.de
- added obsolete driver module 'eepro100' to blacklist (Bug 146728)
- added obsolete driver module 'sk98lin' to blacklist (Bug 146930)
- renamed script /etc/NetworkManager/dispatcher/nm_start_services
  to netcontrol_services
- added /etc/NetworkManager/dispatcher/netcontrol_global_hooks
  that calls all scripts in if-{up,down}.d. It respects variables
  GLOBAL_PRE_{DOWN,UP}_EXEC
* Mon Jan 30 2006 zoz@suse.de
- new version 0.50.2
- disabled (un)plug beeps of ifplugd (Bug 145626)
- status files were moved to from /var/run/sysconfig to
  /dev/shm/sysconfig (17 days ago). Now also routing status files
  moved there. (/var is sometimes not available early enough)
- made mount.sh much faster in the no operation case.
* Sun Jan 29 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 27 2006 zoz@suse.de
- fixed /lib/udev/mount.sh: It must mount only devices which have a
  line in fstab that contains mount option hotplug. (Bug 145400)
* Tue Jan 24 2006 zoz@suse.de
- Also set LLADDR if BOOTPROTO=dhcp
- Also set LLADDR and MTU if BOOTPROTO=autoip
- Added a note to /e/s/n/config:IFPLUGD_OPTIONS how to make
  ifplugd silent (Bug 145626)
* Mon Jan 23 2006 jg@suse.de
- ifup-wireless:
  + do not prefer wpa_supplicant for non-WPA connections
    (bug 129610, 141591)
  + fixed incorrect error message
  + fixed faulty wpa_supplicant.conf generation when WPA-EAP
    is configured
* Mon Jan 23 2006 zoz@suse.de
- New version 0.50.1
- simplified mount.sh. Both fsck and mount can deal with links to
  device nodes.
- Let NetworkManager start services via ifup-services:
  + added /etc/NetworkManager/dispatcher.d/nm_dispatcher_services
  + enabled ifstatus-services
  + let ifup-services also look in ifservices-<interface>[-<essid>]
    or just ifservices if ifservices-<config> did not exist
  + made ifup-services a bit more verbose
  + added a paragraph about that in ifservices.5
- NetworkManager now lives in /usr/sbin. Adapted accordant variables.
- Add ifcfg variable INTERFACETYPE. It it is unset INTERFACETYPE will
  be taken from getcfg or as fallback from interface name. (Bug 142976)
- rcnetwork:
  + it did not start netcontrol if NM is not installed. Fixed function
    nm_running() to make this work again.
  + fixed actions stop and start for cases where both NM and NetControl
    are running (by mistake) and when changing between them.
- sysconfig/{network,hardware}/config are now also handled by fillup
- ifup assumes NM_CONTROLLED=no for all interface types except eth, tr
  and wlan if NM_CONTROLLED is not set in config file. (Bug 143729)
* Thu Jan 19 2006 zoz@suse.de
- uncommented ide and input rules in 80-sysconfig.rules
- check if NM is installed before checking if running (Bug 144032)
* Wed Jan 18 2006 aj@suse.de
- Fix insserv network.
* Tue Jan 17 2006 zoz@suse.de
- added info about ifrenew and ifprobe to manpage ifup.8
* Mon Jan 16 2006 zoz@suse.de
- ifup/down/status now checks if NetworkManager is running. ifup
  will advise NetworkManager to set up the interface.
  A new variable NM_CONTROLLED can be used to make an interface
  manually controllable by ifup.
- ignore flag '__NSC__' in autogenerated list of mandatory devices
  in rcnetwork
- ifstatus returns proper value for interfaces configured with
  STARTMODE=ifplugd. Allows rcnetwork to wait for plugged interfaces.
  (Bug 141554)
- Added module dpt_i2o to blacklist (Bug 129301)
- Added script links ifrenew and ifrenew-dhcp. This allows to renew
  a dhcp lease without changing other interface settings (e.g.
  wlan settings). (Bug 143329)
* Mon Jan 16 2006 zoz@suse.de
- new version 0.50.0
- hwup: added 'ide' in the list of known subsystem.
- ifup: enhance output for rcnetwork
- rcnetwork:
  + source functions.common after evaluation of options to
    make option 'debug' work with new output functions.
    See changeset 1344
  + removed old and unused extra message
  + start NetworkManager and NetworkManagerDispatcher from here
    if new variables NETWORKMANAGER and NM_DISPATCHER are set
    suitably. (Bug 135595)
  + added therefore dbus and haldaemon to Required-Start.
- removed old code that was commented out since long
- added /lib/udev/mount.sh from udev package together with udev rules
  /etc/udev/rules/85-mount-fstab.rules.
  Removed sysconfig variables from sysconfig/storage, because they
  are useless.
* Sun Jan 15 2006 zoz@suse.de
- getcfg now quotes the content of the listed variables
* Fri Jan 13 2006 zoz@suse.de
- old output functions now use the new ones (*mesg). From now on
  only the new ones should be used for new code.
- Removed option 'quiet' from all scripts. Redirect output instead.
* Fri Jan 13 2006 hare@suse.de
- hwdown:
  + use right bus id for unbinding from drivers
  + don't exit if device has no driver link
* Tue Jan 10 2006 werner@suse.de
- poll-tcpip: if not xntp is running just run ntpdate
* Thu Jan  5 2006 zoz@suse.de
- rcnetwork: also consider devices with startmode ifplugd mandatory
  (bug 141554)
* Mon Dec 19 2005 zoz@suse.de
- Version 0.42.0
- hwup/down: (changes from sscheler@suse.de)
  + never unload modules but unbind drivers instead. There
    is also a new variable DRIVER for hwcfg-* files where a driver
    can be specified.
  + return value != 0 if module could not be loaded.
- New ifcfg-* variable ETHTOOL_OPTIONS: if not empty ifup will call
  ethtool with exactly this options.
* Mon Dec 19 2005 hare@suse.de
- Version 0.41.2
* Thu Dec 15 2005 zoz@suse.de
- added if{down,status}-bridge links (Bug 138436)
- ifup: call if{down,status}-bridge only if needed (Bug 138436)
* Wed Dec 14 2005 hare@suse.de
- getcfg: rewrote split_hwdesc(). No quoting required anymore.
- Update documentation to reflect the change.
* Mon Dec 12 2005 jg@suse.de
- ifup-wireless: Added some more WPA config variables
- moved all variables from /etc/sysconfig/network/wireless to
  ifcfg.template
- documented all used WLAN variables in ifcfg.template
- removed /etc/sysconfig/network/wireless
- removed partly outdated variables documentation from
  ifcfg-wireless manpage in favour of ifcfg.template documentation
- set version to 0.41.1
* Thu Dec  8 2005 zoz@suse.de
- Updated manpages and ifcfg.template
- Added manpage ifservices (5)
- Added support for interface bridging inclusive manpage and
  sysconfig metadata (by sscheler@suse.de, bug 44708, feature 2307)
- suppress 'grep' error messsage in postinstall script (bug 137774)
- Added 80-sysconfig.rules to package (was in udev before)
* Wed Nov 30 2005 jg@suse.de
- ifup-wireless: changed incorrect 'private_key_password' to
  'private_key_passwd' for wpa_supplicant.conf
* Fri Nov 25 2005 zoz@suse.de
- ifstatus did sometimes report success for an interface while a
  background ifup was just setting up this interface with dhcp.
  Fixed that. (bug 134899)
- hwup: subsystem input_devices is now input
- added functions.pnp really to filelist
* Thu Nov 17 2005 zoz@suse.de
- ifup: removed old workaround for PC-cards
- functions: made reading specific values from config files more
  robust (where we cannot just source them)
- added /etc/ssconfig/hardware/scripts/functions.pnp. It loads
  modules based on id attribute since pnp does not have MODALIAS.
* Wed Nov 16 2005 jg@suse.de
- Automatically creating ath interface for Atheros WLAN cards
  (bug 133284)
* Thu Nov  3 2005 zoz@suse.de
- fixed superfluous error message in ifdown-route
  (See bug 87338, comment 38 - 41)
- added vio to known subsystems in hwup (bug 56865, comment 74)
- added service isdn to network:should-start and removed no longer
  existing services coldplug and pcmcia (Bug 131741)
* Fri Oct 28 2005 zoz@suse.de
- added README.storage
* Thu Oct 27 2005 zoz@suse.de
- moved /etc/hotplug/blacklist to /etc/modprobe.d/ and removed
  special blacklist handling from hwup. modprobe will do this job.
- moved /sbin/rename_netiface and /sbin/udev.trigger_firmware_loading.sh
  to /lib/udev
* Thu Oct 27 2005 jg@suse.de
- ifup-wireless:
  + Do not prefer wpa_supplicant for prism54 (bug 131007)
  + Fixed fault WPA-PSK handling in wpa_supplicant.conf generation
    (bugs 118157 and 130163)
  + Shut down wpa_supplicant on ifdown even when interface is
    not available anymore (bug 131010)
* Mon Oct 24 2005 zoz@suse.de
- rcnetwork:
  + return 'failed' if non physical interface (e.g. vlan) could
    not be set up (Bug 128673)
  + make all devices that serve for bonding, vlan or tunnels
    mandatory devices (Bug 95834 - LTC16580)
  + Don't gather the existence from a ifcfg-<interface> file>
    (Bug 128823)
- ifup-802.1q (vlan): Don't complain if ethernet device is not up.
  Just set it up instead. (Bug 128665)
- Make rcnetwork restart work better (Bug 129648):
  + ifdown: don't return before ifplugd has terminated
  + functions: get_priority(): exclude comments when grepping for variables
* Fri Oct 21 2005 mmj@suse.de
- New iproute2 is more strict with the syntax
* Fri Sep 30 2005 poeml@suse.de
- if the IP address changes, reload syslog [#116466]
* Thu Sep 29 2005 zoz@suse.de
- fixed changes from Fri Apr 22 12:08:52; vlan interfaces did not
  work anymore since this change (Bug 95556)
* Mon Sep 26 2005 werner@suse.de
- Remove comments not only if empty in poll.tcpip
* Fri Sep  9 2005 jg@suse.de
- ifup-wireless: removing seperator characters from hex WEP keys
  (bug 116083)
* Tue Sep  6 2005 jg@suse.de
- ifup-wireless: changed AP scan mode default for ipw2100 devices
  (bug 115209)
* Tue Sep  6 2005 zoz@suse.de
- added slamr and slusb to blacklist (bug 115132)
* Mon Sep  5 2005 zoz@suse.de
- Enhanced the way how to fake ifplugd for wlan interfaces. If no
  cable is plugged rcnetwork did not set up the wlan iface.
- Don't load modules for PCMCIA bridges if pcmcia=off at bootprompt
- Added README.Persistent_Interface_Names
- ifup prints a warning of PERSISTENT_NAME is still used
- Set USE_SYSLOG back to yes
* Sun Sep  4 2005 schwab@suse.de
- Spelling fixes.
* Fri Sep  2 2005 jg@suse.de
- Do not start ifplugd for wireless devices, assume link status
  'yes' instead (makes WPA configurations in conjunction ifplugd
  possbile)
- Use timeout defaults of ifplugd instead of using extra long
  ifdown timeout; it is not necessary because ifplugd is not used
  anymore on wireless devices which needed the long timeout
* Thu Sep  1 2005 zoz@suse.de
- Moved rule for firmware-patch in seperate file and leave
  30-net_persistent_names.rules %%config(noreplace) (Bug 114662)
- Rewrote check for rcnetwork if interfaces are already renamed or
  not. Did not use timestamps this time. (Bug 112909)
* Thu Sep  1 2005 jg@suse.de
- ifp-wireless:
  + Do not use wpa_supplicant in case WIRELESS_MODE is not 'Managed'
  + Set PREFER_WPA_SUPPLICANT to 'no' when ndiswrapper
    is detected (bug 113635)
* Thu Sep  1 2005 zoz@suse.de
- Added tpm* modules to blacklist (bug 113546)
* Mon Aug 29 2005 schwab@suse.de
- Make sure PATH is exported.
- Always source config before scripts/functions.
* Mon Aug 29 2005 zoz@suse.de
  version 0.40.4
- poll-tcpip: rcxntpd has moved to rcntp (bug 113569)
- Don't call ifup-wireless as an exclusive ifup-<interfacetype> if
  interface name is 'wireless'. (bug 83786)
- Do not prefer wpa_supplicant if no ESSID is given. (by jg)
- added /sbin/udev.trigger_firmware_loading.sh as a workaround for
  broken drivers that don't load firmware immediately. This requires
  also modified rules in 30-net*.rules. (bug 113385)
* Sat Aug 27 2005 schwab@suse.de
- Handle macio subsystem in hwup.
* Fri Aug 26 2005 zoz@suse.de
  version 0.40.3
- rcnetwork: Timestamps for new interfaces may have future time
  during installation. Therfore we don't skip interfaces at all
  when called from YaST. (bug 112909)
- Make hwup handle static configurations again (bug 113158)
- Added ra* interfaces to the list of names that should be made
  persistent via rename_netiface
- Removed static libs (bug 105815)
- Changed sysconfig variable LOG_LEVEL to DEFAULT_LOG_LEVEL
* Wed Aug 24 2005 schwab@suse.de
- Adjust defaults to agree with current defaults.
* Wed Aug 24 2005 zoz@suse.de
  version 0.40.2
- added missing fb modules to blacklist (bug 106715)
* Mon Aug 22 2005 zoz@suse.de
  version 0.40.1
- rcnetwork:
  + make 'status' work again (broken since version 0.33)
  + 'reload' does nothing if network was not started
  (both are related to bug 106040)
* Mon Aug 22 2005 jg@suse.de
- ifup-wireless:
  fixed print_key function for hex keys (bug 106051)
  using new log message functions
  added support for WEP keys up to 232 bit when entered as ASCII
* Mon Aug 22 2005 zoz@suse.de
- new version 0.40.0
- Changed hwup:
  + prepared removal of getcfg
  + restructured first part of hwup that collects information. It
    checks the subsystem and calls specific subsystem functions if
    these are defined. These may be defined in functions.<subsystem>.
  + it now uses new output functions which respect udev loglevel.
  + allow spaces in config file names. Yes, ugly, but pcmcia may need it.
- added functions.susbsystem.template
- Add new config variable LOG_LEVEL and mark DEBUG as deprecated in
  hardware/config. Backward compliance: DEBUG==yes ==> LOG_LEVEL=7
- Also change default of USE_SYSLOG to "no".
- removed FAILURE_ACTION completely, we will never use that
* Fri Aug 19 2005 ro@suse.de
- move static lib and la file to /usr
* Thu Aug 18 2005 zoz@suse.de
- ifup: removed switch USE_IPV6, because it is silly. (Bug 105436)
- hardware/scripts/functions: cleaned up
* Wed Aug 17 2005 zoz@suse.de
- functions.common: added new functions {,err,info,debug}_mesg()
  If not set explicitely via LOG_LEVEL these check the udev loglevel.
- rename_netiface:
  + removed logging into a file in /tmp (Bug 104606)
  + use mktemp for temporary files
* Tue Aug 16 2005 zoz@suse.de
- added blacklist from obsolete hotplug package. This file is now
  used by hwup.
- rpm%%post removes old autogenerated device configuration files.
* Thu Aug 11 2005 zoz@suse.de
- ifup did not use the config from commandline if there was an
  ifcfg-$INTERFACE due to a vlan/bonding workaround.
  Fixed this workaround now.
* Wed Aug 10 2005 zoz@suse.de
- Changed hack from Mon Aug  8 10:04:13
  rcnetwork now ignores at boottime only interfaces which are so new
  that there is still an instance of ifup running and waiting for
  service network to be activated.
* Mon Aug  8 2005 zoz@suse.de
- 'rcnetwork reload' now also checks /etc/sysconfig/network/routes.
  (Bug 100126)
- ifup: removed invalid option from logerror
* Mon Aug  8 2005 zoz@suse.de
- added hack to enable network interfaces after installetion
* Fri Aug  5 2005 zoz@suse.de
- rcnetwork: skip ethernet interfaces from /sys/class/net only
    at boot time
* Fri Aug  5 2005 zoz@suse.de
- fixed timestamps and added missing \ in Makefile.am
- New version 0.33
* Fri Aug  5 2005 zoz@suse.de
- hwup: Don't load modules via $MODALIAS unconditionally, but check
    /etc/hotplug/blacklist before. This does not affect modules
    specified in hwcfg-* files.
- ifup: set MTU before and after the interface is set UP (Bug 94015)
- added /sbin/rename_netiface and a udev rule to make all eth*, ath*
  and wlan* network interface names persistent. Missing rules for new
  interfaces will be autocreated.
* Fri Aug  5 2005 jg@suse.de
- removed obsolete ifup-wireless-wpa
- ifup-wireless: new variables for hidden ssid support and AP
  scan mode
- updated ifcfg-wireless man page
* Thu Aug  4 2005 zoz@suse.de
- getcfg again prints a complete 'export' line. (Bug 97579)
- added typo fix from Wed Jul 27 to SVN and removed sysconfig-0.32.0.diff
* Thu Jul 28 2005 jg@suse.de
- ifup-wireless: fixed typo which broke non-WPA configuration
    when using wpa_supplicant
* Wed Jul 27 2005 schwab@suse.de
- Fix comment typo.
* Tue Jul 26 2005 jg@suse.de
- create ifdown-wireless symlink
* Mon Jul 25 2005 jg@suse.de
- ifup-wireless: incorporated ifup-wireless-wpa
- ifup-wireless: added wpa_supplicant support for non WPA modes
- ifup-wireless: added multiple network support
* Mon Jul 18 2005 jg@suse.de
- ifup-wireless-wpa: added WPA-EAP support
* Mon Jul 11 2005 jg@suse.de
- ifup-wireless-wpa: added pidfile command line option to
  wpa_supplicant call
* Mon Jul 11 2005 jg@suse.de
- ifup-wireless-wpa: fixed wrong wpa_supplicant.conf generation
  for WPA hex keys
- ifup-wireless-wpa: support hidden SSID
- ifup-wireless: added support for shared key authentication with
  madwifi driver
* Thu Jun 23 2005 hare@suse.de
- Automatic module loading from hwup if no configuration is found.
* Thu Jun 16 2005 poeml@suse.de
- ifup-dhcp: explicitely call dhcpcd with -c
  /etc/sysconfig/network/scripts/dhcpcd-hook, unless
  DHCLIENT_SCRIPT_EXE is set otherwise, reflecting changed default
  in dhcpcd [#85849]
- fix neededforbuild, libsysfs is now in package sysfsutils
* Fri Jun 10 2005 zoz@suse.de
- ifup/down: exit if called with option dhcp but BOOTPROTO!=dhcp. (Bug 85849)
* Thu Apr 28 2005 zoz@suse.de
- modify_resolvconf: Don't reload lwresd if it is not installed (Bug 80295)
* Mon Apr 25 2005 jg@suse.de
- ifup-wireless-wpa: fixed typo breaking ndiswrapper WPA support
* Fri Apr 22 2005 zoz@suse.de
- ifcfg-bonding.5: new manpage for interface bonding
- ifup-802.1q: avoid superflouos and misleading error messages
- ifup, ifup.8: Updated description of options of ifup
- ifup-route: fixed patch for bug 65557 (from 2005/3/17)
- ifup:
  + get right config for vlan and bonding interfaces
  + Don't unnecessarily complain when setup bonding interfaces that
    have only labeled v4 addresses (Bug 64489).
    Also allow dhcp with bonding interfaces.
  + Call PRE_DOWN_SCRIPT always, even if BOOTPROTO=dhcp and DHCP!=yes.
    (Bug 61842)
  + If BOOTPROTO=dhcp and dhcp still got no lease then return R_DHCP_BG.
    This lets rcnetwork wait (if interface is mandatory) (Bug 75905)
- ifdown: Check if there are interfaces which are based upon the
  current and take these down first. This works currently only for
  bonding and vlan (Bug 66945)
- hwdown:
  + Changed the way we check which module to unload (belongs to bug 59794)
  + Don't unload modules when called from hotplug (Bug 79319)
- dhcpcd-hook: Don't call ifdown when going down, because PRE_DOWN
  jobs will now be executed directly from first ifdown run (Bug 61842)
* Sat Mar 19 2005 aj@suse.de
- Do not leave empty files around with modify_resolvconf [#73841].
* Thu Mar 17 2005 zoz@suse.de
- ifup-route: don't add a linklocal route if interface has no v4
  adress (Bug 65557)
* Wed Mar 16 2005 ro@suse.de
- re-create tarball to change files in the future
* Tue Mar 15 2005 zoz@suse.de
- rcnetwork: Use $INIT_VERSION to check if we were called from init (Bug 71230)
- ifup-ppp: unified names for smpppd options variable (Bug 72782)
- ifup: also change interface name to PERSISTENT_NAME if called with
  '-o rc'. Now rcnetwork restart will change the names and there will
  (hopefully) no more race conditions at boot time (Bug 65497)
* Sun Mar 13 2005 zoz@suse.de
- modify_resolvconf: exit immediately if /tmp is readonly (Bug 50243)
* Wed Mar  9 2005 zoz@suse.de
- getcfg: look in /proc/net/wireless if interface is type wlan
- modify_resolvconf: reload lwresd after resolv.conf has changed
* Mon Mar  7 2005 jg@suse.de
- doc/ifcfg-wireless.5: documented WIRELESS_WPA_CONF variable
* Sat Mar  5 2005 schwab@suse.de
- Echo newline after dhcp info.
* Fri Mar  4 2005 jg@suse.de
- ifup-wireless-wpa:
  - fixed support for ipw2x00 devices
  - added support for user supplied wpa_supplicant.conf
* Wed Mar  2 2005 zoz@suse.de
- Change default of sysconfig variable. New:
  /etc/sysconfig/network/dhcp:DHCLIENT_KEEP_SEARCHLIST=yes (Bug 65982)
* Mon Feb 28 2005 jg@suse.de
- ifup-wireless(-wpa): using HWD_INTERFACETYPE_0 instead of
  obsolete HWD_DEVTYPE to check for wlan devices (bug 66009)
* Mon Feb 28 2005 zoz@suse.de
- fixed function get_ifplugd_priority which got wrong priorities for
  interfaces without a configuration. (Bug 65256)
- fixed getcfg to find configuration named by interface (Bug 65256)
- fixed getcfg to find configurations by id for wlan interfaces (Bug 66685)
- fixed getcfg to properly determine buslist
- fixed getcfg not to prefer configuration by bus-pci over _more_ specific
  bus-pcmcia or bus-usb configurations.
- rcnetwork: Don't start lo again if it's already up (Bug 64265)
- ifup-wireless-wpa now uses HWD_DRIVER to determine driver (Bug 65533)
* Mon Jan 17 2005 schwab@suse.de
- modify_resolvconf: fix quoting in arguments of eval.
* Tue Jan 11 2005 hare@suse.de
- Fix devicepath detection for network devices (#49729).
- Removed loop while looking for a hwcfg file.
* Mon Jan 10 2005 hare@suse.de
- Use error_log() for debugging messages.
- Fix '-v' to accept numeric arguments.
* Mon Jan 10 2005 hare@suse.de
- Do not print debugging output for non-debugging builds (#49643).
* Wed Dec 29 2004 poeml@suse.de
- version 0.32.0
- libgetconfig updates (from hare):
  - Major rewrite of get_config_lib. Do avoid scanning wherever
    possible. Old version did not scale properly with many devices.
  - Fixed getcfg for PCMCIA
- increase libgetconfig's libtool library version to 2:0:1
- remove the obsolete convenience wrapper /sbin/rcdhclient
* Fri Dec 10 2004 zoz@suse.de
- ifdown-route does not remove default route if there is still an
  active interface in this subnet (Bug 49123)
- poll-tcpip: try-restart ntpd or call ntptimeset (Bug 48654)
- cosmetical changes in ifup-ppp, ifup-dhcp, ifup-skel, functions
* Wed Dec  8 2004 zoz@suse.de
- make modify_resolvconf work without /usr (Bug 25592)
* Tue Dec  7 2004 poeml@suse.de
- add -lsysfs only where needed
- fix missing includes in autoip.c, and in doing so fix the format
  string used in readlink() call
- convert_for_getconfig:
  - if a hwcfg-static-0 file has been created during system update,
    attach a note about that to the ifcfg files [#40244]
  - add quotes around some variables for the fix of bug 38285
    (parsing of route file), to make parsing more robust in some
    weird configurations (found during testing)
  - run only during package update, not in new installation
* Sat Dec  4 2004 zoz@suse.de
- fixed handling of status and status files for dsl and modem (Bug 43950)
* Tue Nov 30 2004 zoz@suse.de
- ifup does not longer create status files for interfaces without
  configuration (Bug 43949)
* Wed Nov 24 2004 hare@suse.de
- Fixed getcfg to do a proper reverse-mapping for grouped devices
  on S/390 (#42709).
* Fri Nov 12 2004 zoz@suse.de
- ifup:
  + set up additional static addresses if BOOTPROTO=dhcp (Bug 47399)
  + POST_*_SCRIPTS are now also executed for ppp interfaces (Bug 44147)
  + Don't check MODE in ifstatus (Bug 48132)
- ifstatus-dhcp:
  + check if the running dhcp client serves current interface (Bug 48130)
  + skip some output, since ifup also performs check for static
    addresses (Problem was a result of fixing bug 47399)
- rcnetwork:
  + skip ifcfg*rpm{new,save} when looking for mandatory devices (Bug 48119)
* Mon Nov  8 2004 zoz@suse.de
- ifdown-dhcp reports an error if interface does not exist, except
  if called with -o hotplug (Bug 47536)
* Tue Nov  2 2004 zoz@suse.de
- extended getcfg to report the driver name of a device. (Note that
  this name might differ from the module name of the driver module)
- hwdown tries to unload the module that was really used for a device
  and not that from hwcfg-*. (Bug 44794)
* Wed Oct 27 2004 jg@suse.de
- ifup-wireless-wpa:
  - make wpa config file non world-readable (bug 47043)
  - added support for ndiswrapper (bug 47042)
  - checking for already running wpa_supplicant before starting it
  - fixed check for failed driver detection
- ifup-wireless: removed no-encryption-used warning when WPA-PSK
  is being used
* Fri Oct  1 2004 zoz@suse.de
- ignore interfaces wifi* in rcnetwork (Bug 46408)
- add a workaround to get the interface name of hardware descriptions
  like *bus-pcmcia* or *bus-usb* (Bug 46387)
* Fri Oct  1 2004 jg@suse.de
- added manpage ifcfg-wireless.5
* Thu Sep 30 2004 jg@suse.de
- ifup-wireless-wpa: fixed broken driver detection (bug 46528)
- ifup-wireless-wpa: added ipw2100 as supported driver (bug 46528)
* Wed Sep 29 2004 jg@suse.de
- ifup-wireless-wpa: removed scan_ssid=1 from generated
  wpa_supplicant.conf, as it is not supported by ipw2100 driver
* Tue Sep 28 2004 poeml@suse.de
- avoid stray output during package update to avoid confusion
* Tue Sep 28 2004 zoz@suse.de
- When checking if firewall has to be started and when current runlevel
  is undefined (at installation time), then use default runlevel. And
  ifstatus checks if setting up firewall is still in progress (Bug 46043)
- suppress unimportant messages in ifdown-wireless{,-wpa}
* Sun Sep 26 2004 zoz@suse.de
- functions: made definition of RUN_FILES_BASE easier and more robust
- rcnetwork: reload firewall after manual start of service (scpm needs
  that) (Bug 45997)
* Fri Sep 24 2004 zoz@suse.de
- ifup: don't use 'cardctl ident' to obtain device description of
  PC-Cards, becasue it interferes with 'cardctl eject' (Bug 44290)
* Thu Sep 23 2004 jg@suse.de
- ifup-wireless-wpa (this time for real)
  - removed bogus is_iface_up check
  - doing status check only when wpa is configured
  - checking for wpa_cli before calling it
* Mon Sep 20 2004 kkeil@suse.de
- handle update USERCONTROL for dialin network devices (#43650)
* Sat Sep 18 2004 zoz@suse.de
- modify_resolvconf: handle spaces in the values of the info block,
  e.g. multiple process ids (Bug 45395)
* Fri Sep 17 2004 poeml@suse.de
- enable UDP checksumming by dhcpcd again; all known issues have
  been resolved [#44670]
* Fri Sep 17 2004 zoz@suse.de
- made sourcing config files save in all occurences (Bug 42947)
* Thu Sep 16 2004 jg@suse.de
- ifup-wireless-wpa:
  - removed bogus is_iface_up check
  - doing status check only when wpa is configured
  - checking for wpa_cli before calling it
* Wed Sep 15 2004 werner@suse.de
- poll.tcpip: if sendmail is used throw out client and master
  mail queue (bug #45309)
* Mon Sep 13 2004 poeml@suse.de
- handle a special case during updates of the routes file (set default
  route to default interface) [#38285]
* Mon Sep 13 2004 zoz@suse.de
- startscript always waits for mandatory dhcp interfaces until they
  have got a lease, also if they were already started in background
  via hotplug. (Bug 44877)
- /etc/sysconfig/network/config: changed default options for ifplugd:
  removed '-a' to set interfaces UP by ifplugd. (Bug 45040)
* Thu Sep  9 2004 zoz@suse.de
- functions:
  + *_cached_config_data(): check if $RUN_FILES_BASE/tmp is
    existing and writeable  (Bug 43943)
- implemeted module unloading in hwdown (Bug 44794)
* Tue Sep  7 2004 zoz@suse.de
- ifdown:
  + write a message if there is no interface an we are called manually
    (with hotplug we have to act on non-existing interfaces) (Bug 44576)
  + check earlier if interface is available and don't write status
    files on ifup, if interface does not exist. (Bug 44319)
- ifup:
  + call ifup-wireless after starting ifplugd (Bug 44765)
  + check if service network was started before starting ifplugd (Bug 44764)
* Tue Sep  7 2004 jg@suse.de
- ifup-wireless-wpa: shut down wpa_supplicant even interface is
  not available
* Mon Sep  6 2004 poeml@suse.de
- disable the recently enabled UDP checksumming by dhcpcd. It
  often doesn't seem to work. [#44670]
* Mon Sep  6 2004 zoz@suse.de
- rcnetwork: create /var/run/sysconfig/tmp when starting network
  (broken on 2.9.2004: "'-o onboot' now really behaves as if ..."
- ifprobe: fixed check for down interfaces
* Sat Sep  4 2004 zoz@suse.de
- Now officially skip support for bootp. (Bug 43299)
- modem configuration files may now be called ifcfg-modem* (Bug 43651)
  Removed if*-dsl links, because we now call if*-ppp explicitely for
  all pppd based devices.
* Fri Sep  3 2004 zoz@suse.de
- added new link to ifup: ifprobe
  It checks if configuration for the interface has changed since last
  ifup. Returns 0 if config is up to date.
- implemented reload in rcnetwork using ifprobe.
* Thu Sep  2 2004 zoz@suse.de
- Changed meaning of IFPLUGD_OPTIONS: It is not longer for additional
  options but lives in /etc/sysconfig/network/config and contains
  the default options. To be oevrwritten in ifcfg-*
- Added variable USE_IPV6 (=yes) to /etc/sysconfig/network/config.
  If 'no' then ifup always flushes all ipv6 addresses. (Needed if
  ifplugd needs an interface to be up to detect link beat.)
- rcnetwork:
  + '-o onboot' now really behaves as if called at runlevel switch
  + don't start interfaces twice when given as argument (Bug 41832)
- ifdown writes an error message if no config was found (Bug 44576)
- ifup now calls SuSEfirewall in the second run when BOOTPROTO=dhcp.
  And it does not call firewall if called from rcnetwork. (Bug 44524)
* Tue Aug 31 2004 jg@suse.de
- ifup, ifup-wireless, ifup-wireless-wpa: removed WPA stuff from
  ifup-wireless and created ifup-wireless-wpa for WPA functionalty
* Tue Aug 31 2004 zoz@suse.de
- ifup: Don't call helper scripts in second run (dhcp)
- ifup-services:
  + renamed directory for rc-links to ifservices-<config name>
  + avoid error message if ifservices-* directory is empty
- functions:
  + *_cached_config_data(): check if $RUN_FILES_BASE is
    writeable (usually /var/run/sysconfig) (Bug 43943)
  + removed old unused functions and fixed typo
* Mon Aug 30 2004 poeml@suse.de
- version 0.31.3
- automatically draw ChangeLog from the source code repository
* Mon Aug 30 2004 zoz@suse.de
- ifup:
  + added new STARTMODE 'ifplugd'. When set ifup will just start
    ifplugd and exit if called with '-o hotplug' or '-o rc'.
  + added new variable IFPLUGD_OPTIONS to set individual options
    for ifplugd
  + added new variable IFPLUGD_PRIORITY. If set to an positive
    integer this interface will be used alternatively with others
    that have this variable set. This is controlled by ifplugd via
    new script 'ifplugd-selectif'
* Fri Aug 27 2004 poeml@suse.de
- dhcpcd: calculate UDP checksum on received packets. A new
  variable in /etc/sysconfig/network/dhcp, DHCLIENT_UDP_CHECKSUM,
  controls this behaviour.
* Fri Aug 27 2004 jg@suse.de
- added WPA-PSK support
- prevent WEP keys from being logged (Bug 43966)
* Thu Aug 26 2004 mvidner@suse.de
- split up ifcfg documentation from ifup and updated variable
  description.
* Mon Aug 16 2004 arvin@suse.de
- create ifcfg-modem0 instead of ifcfg-ppp0 during update from pre 8.0
* Mon Aug  9 2004 zoz@suse.de
- Now version 0.31.2
- functions: *_cached_config_data(): major changes
  + deal with interface names or configuration names
  + write changes in an atomic way (modify tempfile, move it then)
  + modfifications will have to be commited up to now with
    commit_cached_config_data()
  + updated comments
- ifup does now write status information to $RUN_FILES_BASE/if-*. To
  achive this we now use an exithook which may be called to set the
  final status and trap exit to finally write this state. Status files
  will now be written per interface and no longer per used configuration.
- ifdown and ifstatus now use the configuration that was used for ifup
  and only if there is no such information look theirself.
- ifup-dhcp does always return $R_DHCP_BG when it is waiting for a
  lease, not only when called from rcnetwork.
- rcnetwork cleans or creates $RUN_FILES_BASE/tmp/
- default ifcfg-lo now has USERCONTROL=no
* Thu Aug  5 2004 zoz@suse.de
- modify_resolvconf: Don't delete an empty resolv.conf (Bug 40728)
* Wed Jul 14 2004 jg@suse.de
- Fixed setup of wlanng WLAN devices for configurations with
  no WEP encryption
* Mon Jun 28 2004 hare@suse.de
- Added hack to recognize IUCV devices (#42212).
* Fri Jun 25 2004 hare@suse.de
- Fixed script errors in hwdown-scsi.
* Fri Jun 25 2004 hare@suse.de
- Fixed ifcfg for token ring devices (#41174).
* Thu Jun 24 2004 zoz@suse.de
- rcnetwork: write /var/run/sysconfig/network early to avoid a tiny time
  slot in which interfaces have not been set up at boot time (Bug 39005)
* Wed Jun 23 2004 hare@suse.de
- Fixed ifcfg for lcs devices (#40097).
* Mon Jun 21 2004 hare@suse.de
- Added 'eth' and 'tr' as aliases for 'ccw' and 'ccwgroup' (#41461)
* Tue Jun  8 2004 hare@suse.de
- Added option 'fast' to hwup to avoid calls to getcfg (#40616)
* Mon Jun  7 2004 hare@suse.de
- Replaced basename by calls to ${var##*/}.
* Fri Jun  4 2004 hare@suse.de
- Add buffer_count to the list of additional options for S/390
  (#41570).
* Thu Jun  3 2004 hare@suse.de
- Add IP address takeover enabling to S/390 qeth devices (#41570).
- Add hwdown script for IUCV devices.
* Thu Jun  3 2004 hare@suse.de
- Configure additional options for S/390 qeth devices (#41570).
* Tue Jun  1 2004 zoz@suse.de
- also set MTU if BOTTPROTO=dhcp (bug 41178)
* Tue Jun  1 2004 hare@suse.de
- Fixed hwup for S/390 ESCON devices (#41460 - LTC8556)
* Thu May 27 2004 mvidner@suse.cz
- Fixed rcnetwork for sure (#41303).
- removed start-all-dhcp-clients (#38834).
* Thu May 27 2004 jg@suse.de
- Fixed ifup-wireless to properly handle empty
  WIRELESS_AUTH_MODE variables
* Thu May 27 2004 hare@suse.de
- Fix rcnetwork as per autobuild request.
* Tue May 25 2004 zoz@suse.de
- ifup: quoted arguments of printf in status section (Bug 39599)
- modify_resolvconf:
  + add forwarders line to named.conf if there was just a commented
    forwarders line (Bug 40601)
- rcnetwork:
  + added ip6tnl and mip6mnha to the list of physical interface types,
    so that their configs are ignored when starting network (Bug 40354)
  + Added {start,stop}-all-dhcp-clients (Bug 38834)
- getcfg: added lcs to device aliases (hare)
* Fri May 14 2004 hare@suse.de
- Added lcs to device aliases (#40097).
* Wed May 12 2004 hare@suse.de
- Added lcs device configuration
- Moved README.s390 to doc directory and install it by default.
- Added missing documentation files doc/Contents and doc/Network.
* Wed May  5 2004 hare@suse.de
- Fixed scripts to correctly enable DASD devices (#39841).
- Updated scripts to check for failures.
* Tue May  4 2004 kkeil@suse.de
- SuSEfirewall2 should be restarted by default on dialin (#39663)
* Thu Apr 29 2004 hare@suse.de
- Fixed getcfg to return busname ccw instead of ccwgroup.
- Updated /etc/sysconfig/hardware/scripts/* to use common functions.
- Update /etc/sysconfig/hardware/scripts/chandev-to-hwcfg.sh to handle
  add_parms.
- Update spec-file to call chandev-to-hwcfg.sh for upgrade from
  chandev to hwcfg.
* Thu Apr 29 2004 zoz@suse.de
- ifup: also store relation to configurations with STARTMODE off or manual
- hwup:
  + unset all variables starting with MODULE before sourcing configuration file.
  + try to get a config via getcfg several times if called by hotplug.
- getcfg:
  + accept fddi, ctc, iucv, hsi, qeth, escon, myri and xp as
    devtypes in network configuration names
  + if busname is 'ccwgroup' always change it to 'ccw'
* Fri Apr 23 2004 zoz@suse.de
- rcnetwork skips files ending with ~ in list of configurations taken
  as mandatory devices (Bug 38707)
* Wed Apr 21 2004 kkeil@suse.de
- do not call ifup/ifdown in ip-up; breaks DialOnDemand (#39048)
* Wed Apr 21 2004 jg@suse.de
- ifup-wireless:
  - fixed wrong handling of WEP keys with spaces
  - fixed support for multiple WEP keys
  - fixed sharedkey authentication support for wlan-ng devices
* Wed Apr  7 2004 zoz@suse.de
- documentation fixes: README, hwup.8, ifup.8
* Tue Apr  6 2004 poeml@suse.de
- documentation fixes:
  - actually install the new man pages [#36722]
  - README: some more lines, but still far from ready
  - hwup.8: - removed some options wich are not implemented
    currently and adapted to current   state of hwup
- convert_for_getconfig:
  - use configured network driver aliases from old modules.conf to
    create hwcfg-static-0 file, to ensure unchanged interface names
    after system update for backward compatibility [#35445]
* Mon Apr  5 2004 poeml@suse.de
- rename ifcfg-eth-bus-pcmcia* files to ifcfg-wlan-bus-pcmcia*, if
  they contain WIRELESS_ variables [#38430]
- fix informative message during logging of routing conversion
* Mon Apr  5 2004 zoz@suse.de
- ifup: always rename interface if PERSISTENT_NAME is set. Ignore
  startmodes of interface and network for that. (Bug 38313)
- rcnetwork: when listing failed mandatory interfaces distinguish between
  mandatory devices whithout interface and failed interfaces. (Bug 38273)
- added manpages for hw* and getcfg*. Started rewriting README (not finished)
* Mon Apr  5 2004 poeml@suse.de
- convert_for_getconfig [#35445]:
  - add PERSISTENT_NAME suggestion also for DHCP interfaces, since
    it is indeed supposed to work. Improve the added comment about
    PERSISTENT_NAME
  - fix replacement of parent device in dsl configurations; do the
    same with ETHERDEVICE in vlan configurations.
  - convert interface names in /etc/sysconfig/network/routes
  - add preliminary code (not used yet) to find and handle
    ifroute-* files
  - convert all ethernet configurations, even if there is only one
    interface
  - rename wlan configuration files, that could not be converted to
    mac address / bus id to 'ifcfg-type-wlan'
  - ifcfg-pci-... --> ifcfg-bus-pci-... [#38248]
* Sat Apr  3 2004 poeml@suse.de
- more work on convert_for_getconfig [#35445]:
  - try to mount sysfs if it is not mounted
  - do not ignore 'unconfigured' NICs -- the UNIQUE string matches,
    and that should be enough to know
  - do not add a suggested persistant name in case of DHCP since it
    doesn't seem to work there
  - for debugging purposes, add a hook to possibly skip the
    conversion during update
  - some informative log messages went only to the screen, not to
    the log
  - retain permissions of ifcfg file when creating it from scratch
* Sat Apr  3 2004 poeml@suse.de
- gather some info about loaded/configured drivers, for debugging
  and possible later use; improve logging [#35445]
* Sat Apr  3 2004 zoz@suse.de
- hwup does not longer interpret MODULE_OPTION* and MODULE_UNLOAD* as
  additional MODULE* variables.
- added messages for better tracking of module loading
* Fri Apr  2 2004 poeml@suse.de
- more work on convert_for_getconfig [#35445]:
  - convert ethernet configuration to bus location style, or if
    possible, to hardware id style, by looking network cards up in
    hardware database and, if possible, sysfs
  - fix parent id of dsl devices
  - backup old configuration and log update changes
* Fri Apr  2 2004 poeml@suse.de
- convert_for_getconfig:
  - fix detection of startmode [#38074]
  - for aliases, also add NETWORK NETMASK BROADCAST to the parent
    device
* Fri Apr  2 2004 zoz@suse.de
- make hwdown a link and not a copy of hwup, also added hwstatus link
  (Bug 37330, 37504)
- rcnetwork:
  + set up 'dial up' and tunnel interfaces after waiting for mandatory
    interfaces. (Bug 3790)
  + do not add 'dial up' and tunnel interfaces to automaticly derived list of
    mandatory devices
  + removed unnecessary warning from ifup-route (Bug 37307)
  + removed X-UnitedLinux- from Should-St{art,op}
- improved comment in /etc/sysconfig/network/config:MANDATORY_DEVICES
- /sbin/ifup:
  + vlan now gets the right configuration at ifdown (Bug 37940)
  + fixed printing device label
- getcfg-interface: always(!) look in /var/lib/smpppd/ifcfg-<iface>.info if
  there is another interface name (needed for dsl). (Bug 37643)
* Wed Mar 31 2004 zoz@suse.de
- rcnetwork:
  + when getting MANDATORY_DEVICES from list of available configurations
    skip these with STARTMODE!=onboot
  + derive MANDATORY_DEVICES only when called at runlevel change
* Mon Mar 29 2004 zoz@suse.de
- getcfg: fixed segfault (Bug 37350)
- rcnetwork: get interface names for MANDATORY_DEVICES again before each
  status test, because they may change if PERSISTENT_NAME is used (Bug 35731)
- added link /sbin/hwdown -> hwup (Bug 37330) (hare@suse.de)
* Mon Mar 29 2004 zoz@suse.de
- rcnetwork:
  + if MANDATORY_DEVICES is unset then derive it from the list of
    available configurations, excluding lo and bus-{pcmcia|usb} (Bug 35731)
  + enhanced output: write labeling of the device and configuration name
* Sun Mar 28 2004 zoz@suse.de
- ifup-wireless: cleaned up some checks
- functions: added load_bond() and changed is_iface_available
- ifup:
  + rewrote code for bonding interfaces (Bug 28301)
  + new variable TUNNEL_DEVICE for tunnel setup, that can contain
    not only interface names but also hardware descriptions
    (TUNNEL_LOCAL_INTERFACE is now obsolete)
  + ifup now knows the right configuration for already unplugged
    interfaces and stops dhcp client correctly (Bug 36765)
  + don't use chkconfig. It needs perl from /usr/bin. (Bug 36514)
- ifup-ppp: Don't set variable 'OPTIONS' as usual, because it is used
  for different purpose (Bug 36975)
- hwup: don't write error message about no configuration if called
  from hotplug (it pollutes the system log) (Bug 36951)
- rcnetwork status now shows also inactive dial up interfaces (Bug 36963)
* Fri Mar 26 2004 hare@suse.de
- Fixed type aliases (#37090)
* Fri Mar 26 2004 mls@suse.de
- ifup-route: add link-local route so that we can access rendevous
  hardware after detecting them via mdns/slp
* Mon Mar 22 2004 zoz@suse.de
- set FIREWALL=yes as default in /etc/sysconfig/network/config (Bug 33442)
* Mon Mar 22 2004 zoz@suse.de
- getcfg:
  + hare@suse.de fixed compilation bugs and uninitialized variables
  + don't try to get type from bus information, only get type for interfaces.
  + if the type is empty then configurations with type match as well, but
    configuration which have also no type match better.
- hwup
  + will take hardware desscriptions that start with "static" as
    configuration names (needed to set up unrecognizable hardware e.g. ISA)
  + fixed syntax error and messages
* Sun Mar 21 2004 zoz@suse.de
- rcnetwork:
  + always skip sit0
  + fixed debug output
  + start must not set up 'manual' interfaces, even if called from
    command line (Bug 36131, 35755)
  + respect -o type= properly (Bug 35911)
- added script check_configurations to check used configuration names
- fixed command line parsing in some ifup/down-* scripts
- removed usage of basename/dirname
- added calls to getcfg-interface where needed
- fixed name check in ifup-802.1q
- ifstatus-route does not longer wrongly fail
- updated ifup-skel
- getcfg:
  + allow empty types in hardware descriptions, which prevents
    autodetection of the type
  + ignore '0x' in hardware descriptions of type 'vpid' if bus or
    type is pci or pcmcia. Don't ignore '0x' in id.
  + complete bus information for pcmcia devices if only bus info of
    the pcmcia bridge was given and there is a device plugged
  + don't drop multiple bus infos of the same bus type in a row.
    Instead bus information shows complete path from root device
    to leaf device
  + determine the type automatically. If there is an interface
    take it's type, else take the bustype of the device
  + decreased priority of description type 'vpid' to lower then
    interface, because one vpid can match several devices.
- getcfg-interface:
  + added option '--ifacetype, -i' to set the type of interfaces to
    look for (default is 'net', which includes 'eth', 'wlan', ...)
  + added second method to get interface name
* Mon Mar 15 2004 zoz@suse.de
- rcnetwork informs which mandatory interfaces failed
- getcfg-interface don't returns pcmcia_socket* as interface for
  empty pcmcia slots, but fails
* Sun Mar 14 2004 zoz@suse.de
- renamed getconfig to getcfg
- changes in rcnetwork:
  + fixed Bug 35586
  + sit* are not physical interfaces
  + add a hack for beta2: Set MANDATORY_DEVICES automatically if empty.
    This has to be removed again!!!!!
  + don't use a message variable for output from ifup. ifup-dhcp does not
    like that.
  + improved output
  - return 'dead' for unconfigured interfaces only if they are mandatory
  - print 'waiting' if ifup returns $R_DHCP_BG (still no address from dhcp)
  - print time to wait for mandatory interfaces
  + set default for WAIT_FOR_INTERFACES to 20
- changes in ifup
  + when called via hotplug retry getting a configuration several times,
    because cardmgr needs some time to refresh /var/lib/pcmcia/stab
  + improved output to fit better into rcnetwork
- changes in ifup-dhcp
  + return R_DHCP_BG if called from rcnetwork and still no address
  + changed messages to fit better in rcnetwork
  + reduced default waiting time when booting to 5 secs, because rcnetwork
    itself waits for all mandatory interfaces to be up
- in dhcpcd-hook: write errors only to syslog
* Fri Mar 12 2004 mls@suse.de
- add autoip bootproto, also supports dhcp+autoip
* Wed Mar 10 2004 poeml@suse.de
- 0.30.3
- new file /etc/sysconfig/network/ifroute-lo, providing an explicit
  route to the localnet [#34872]
- getconfig (zoz):
  - added function look_pcmcia_stab(..) which opens
    /var/lib/pcmcia/stab to get information about PC-Cards.
    Because PC-Cards driver do not register in sysfs we have no
    other way to find out the relation between interfaces and
    devices.
  - changed complete_hwdesc_sysfs() in many places to make hardware
    descriptions "bus-pcmcia*" work for both PC-Cards and CardBus.
- convert_for_getconfig: ignore ifcfg-lo and add ifcfg-wlan to list
  of interface names that need conversion (poeml)
* Mon Mar  8 2004 poeml@suse.de
- 0.30.2
- add script that updates network configuration files. It is run
  when updating from older sysconfig versions (pre 9.1, before
  getconfig was used) (poeml) [#35445]
- rcnetwork: print unused instead of failed in case of no
  configuration found. (zoz)
- ifup:
  - quoting message to avoid redirection
  - remove possible error due to race in lock handling (which is
    currently off) (zoz)
- getconfig: get devicepath from businfo; get interfacepath from
  devicepath; fixed getting businfo from any path
  - added hw property VPIDREV (VendorProductID REVision)
  - allow any number of fields in type vpid. All the rest goes to
    VPIDREV
  - allow empty fields in vpid. (zoz)
* Mon Mar  8 2004 zoz@suse.de
- added functionality in getconfig*:
  + added hw property VPIDREV (VendorProductID REVision)
  + allow any number of fields in type vpid. All the rest goes to VPIDREV
  + allow empty fields in vpid.
  + in complete_hwdesc*(): get interfacepath from id (only for class net)
  + in complete_hwdesc*(): get interface from interfacepath
  + in complete_hwdesc*(): get devicepath from businfo
  + in complete_hwdesc*(): get interfacepath from devicepath
- some minor fixes
* Thu Mar  4 2004 zoz@suse.de
- fixed rcnetwork restart <interface>
- removed some unnecessary messages
- remove locking from ifup
- some minor fixes and changes in comments
- rcnetwork: recognize also wlanX and athX as interfaces to
  physical devices
- network will now be started after coldplug and pcmcia
- ifup: call ifup/down-services before/after POST_UP/PRE_DOWN Hooks
* Mon Mar  1 2004 poeml@suse.de
- ifup:
  - added option 'auto'
  - don't set up interfaces in mode auto if network was not started
  - add warning about experimental interface renaming feature (zoz)
- ifup-route:
  - don't fail if there is no routing config file (zoz)
- rcnetwork:
  - do not handle some interfaces twice (they were in multiple
    sets)
  - changed output
  - status() of _no_ interface must not return an error
  - if network is not started, don't report down ifaces as 'dead'.
    Use 'unused' in this case. (zoz)
* Mon Mar  1 2004 poeml@suse.de
- 0.30.0
- rcnetwork: rewrite (zoz)
  - We now don't work on all available config files, but on all
    available interfaces. Only modem and tunnel interface names are
    read from configuration names, because they are not always
    present before.
  - Wait some time for interfaces that came up via hotplug in
    paralell
  - Make success of service network depending on a list of
    mandatory interfaces. All other interfaces are allowed to fail.
  - removed all alias stuff. From now on we only support multiple
    addresses in one config file, but no longer extra alias config
    files
- ifup: rewrite (zoz)
  - use getconfig to look for configuration
  - lock ifup for the given hardware description
    (/var/lock/subsys/sysconfig)
  - recognized STARTMODES: auto==onboot==hotplug, manuall, off
  - rename interface if called by hotplug and PERSISTENT_NAME is set
- hwup: (zoz/hare)
  - use getconfig
  - load multiple modules
  - call hwup-$DEVTYPE, if explicitely configured (hare)
  - call hooked scripts
  - HOTPLUG=yes indicates that we are called via hotplug agent;
    agents call hwup with '-o hotplug' (hare)
  - added hwdown-* scripts to allow unconfiguration (hare)
  - Update hwup-* to use getconfig variables (hare)
- ip-up: clean up ip-up, call ifup for POST_UP and PRE_DOWN scripts
  (lnussel)
- removed implicit device initialisation in is_iface_available()
- add /etc/sysconfig/hardware/config (central config file for all
  device-independant settins) (zoz)
- /etc/sysconfig/network/config: new variable MANDATORY_DEVICES
- getconfig:
  - always print BUS_N, CONFIG_N and INTERFACE_N
  - print errormessges and usage to stderr
- libgetconfig
  - look in /etc/sysconfig/hardware and hwcfg per default. For type
    class/net, look in /etc/sysconfig/network/ifcfg-*, otherwise in
    /etc/sysconfig/hardware/hwcfg-*
  - devpath must no longer terminate with '/'
  - accept devpaths relative to /sys (even if these
    devpaths start with a '/', like in hotplug events)
  - read vendor/device IDs from the device path
  - disable normalisation of busid
  - renamed output variable HWDESC_TYPE to HWDESCTYPE
- dhcpcd-hook: fixed comment (lnussel)
- don't ship CVS directories with the tarball
- replace <feedback@suse.de> with <http://www.suse.de/feedback>
* Sat Feb 28 2004 jg@suse.de
- using lwepgen instead of nwepgen for key generation in
  ifup-wireless (nwepgen does not generate useful 104 bit keys)
* Fri Feb 20 2004 hare@suse.de
- Removed hwconfig init-script; it is now done by rccoldplug.
* Thu Feb 12 2004 poeml@suse.de
- 0.24.1
- Update skeleton configuration to include the correct scripts;
  Update conversion script to generate proper config files. (hare)
- getconfig:
  - activated getconfig-interface. It does still not really work
    but print at  least the given interface name. Now it may be
    used in scripts.
  - complete_hwdesc_sysfs(): when looking for buspaths, compare
    also link target with device path, otherwise it might find bus
    devices with the same name but different target.
  - get_configuration(): when comparing bus information, strip
    busnames and busids from root of bustree and try again until
    all busnames/busids are stripped. This way we do not have to
    name the configuration with the whole bustree, if a subtree is
    already unique.
  - added option --multiarg, -m that enables multiple arguments as
    used up to now only for getconfig-make-hwdesc.
  - always normalize businfo. Also normalize businfo in confignames
    for proper comparison. (zoz)
- ifup-wireless:
  - Asking for package 'wireless-tools' instead of 'pcmcia'
    (wlanctl-ng tool was moved).
  - Using nwepgen tool for key generation Clearing WEP key in any
    case now (otherwise and old key from a former device setup may
    remain) (jg)
- merge ro's change (moved libsysfs headers)
* Mon Feb  9 2004 hare@suse.de
- Update hwup-* scripts to use EVENT env-var.
* Mon Feb  2 2004 ro@suse.de
- libsysfs headers have moved
* Thu Jan 29 2004 poeml@suse.de
- getconfig: usage info added, names renamed, specification of
  hardware descriptions / configuration names changed (zoz)
* Mon Jan 26 2004 poeml@suse.de
- 0.24.0
- add shared library lib_getconfig and command line tool getconfig:
  New tool to find best matching configurations for a given
  hardware description.  For details read doc/Specification Section
  "Central Tools" (5.2) (zoz)
- add udev to neededforbuild (for libsysfs)
- in %%post, run ldconfig
- use RPM_OPT_FLAGS and -fPIC
- updated specification
- ifup-dhcp: To make dhcpcd deal with infinite leases as handed out
  by BOOTP servers or misconfigured DHCP servers, 1) do not use
  startproc in ifup-dhcp since it interprets the not running dhcpcd
  as failure; 2) manually shut down the interface when ifdown-dhcp
  is called, since there is no other way of doing it.  [#7669]
- merge latest additions from Hannes into CVS
* Tue Jan 20 2004 hare@suse.de
- Fixed typo in hardware/scripts/hwup-zfcp.
* Tue Jan 20 2004 hare@suse.de
- Update of hwup-ccw; Added configuration of zfcp.
* Fri Jan  9 2004 schwab@suse.de
- Use only plain files for hwcfg-*.
- Fix quoting in hwup.
* Thu Dec 11 2003 hare@suse.de
- Update to work correctly with ash.
* Thu Dec  4 2003 hare@suse.de
- Removed relinking of hwup.
* Thu Dec  4 2003 hare@suse.de
- Added hwconfig implementation. Subject to change.
* Thu Nov 13 2003 zoz@suse.de
- fixed bug in mask2pfxlen: It did not convert 0.0.0.0 to 0
  (Bug 21398)
* Wed Nov 12 2003 zoz@suse.de
- Added vlan documentation to man ifup (Bug 31193)
* Mon Nov 10 2003 jg@suse.de
- scripts/ifup-wireless: Work-around for problems with
  madwifi driver (fixes bug #32761), fix for multiple
  key support for linux-wlanng devices
* Wed Oct 15 2003 mmj@suse.de
- Don't build as root
- Setting WIRELESS to "yes" in case interface type is 'wlan
* Tue Sep 23 2003 mmj@suse.de
- Suppress wireless warning with patch from jg
* Mon Sep 22 2003 mmj@suse.de
- Typo fix from msvec
* Thu Sep 18 2003 mmj@suse.de
- Add support for both types of writing gateway adresses in
  ifroute-sitX. From mludvig. [#30934]
* Wed Sep 17 2003 mmj@suse.de
- Add fix for ifup.8 from mludvig.
* Wed Sep 17 2003 zoz@suse.de
- Moved code in ifup that stripped ALIAS number from HWDESC some
  lines up where HWDESC is still unmodified. That fixes a loop
  triggered by 'ifup <hwdesc> <iface> -o hotplug doalias' if there
  are alias configurations. (Bug 31048).
- added debug message if ifup calls itself for alias configuration.
* Tue Sep 16 2003 zoz@suse.de
- Don't call ifup-route with alias but only with master interface
  (happened with '-o dhcp')
- LABEL was not set for aliases (alias were set up, but could not
  be seen with ifconfig)
- ifdown-connection now checks the master interface if called with
  an alias (Same bug we had earlier in ifup-wireless)
* Tue Sep 16 2003 zoz@suse.de
- write also hwdesc<->mode relations to the cache when
  hwdesc<->interface relation is written. Then remember the mode
  and add it to the recursive ifup call. (Bug 31048)
* Mon Sep 15 2003 mmj@suse.de
- The ethtool info is slightly different in 2.6, so add fix from
  Gerd Knorr to handle both 2.4 and 2.6 [#30908]
* Mon Sep 15 2003 jg@suse.de
- Prevent empty keys from being set for wlan-ng devices
* Mon Sep 15 2003 zoz@suse.de
- Undo changes between 1.82 and 1.83 partially: If ifup is called
  with '-o rc' and STARTMODE=manual then look for a cached
  interface <-> config relation (= was set up manually before).
  Otherwise leave this interface untouched. (Bug 30763)
* Mon Sep 15 2003 zoz@suse.de
- Don't ask ethtool for info from unavailable interfaces, because
  tries to 'modprobe' the interface. This results in unnecessary
  error messages at boottime with e.g. dsl interfaces (Bug 30571)
* Mon Sep  8 2003 zoz@suse.de
- added and fixed some comments
- added delete_cached_hwdesc_file() to functions
- ifup: Set INTERFACE="" because it is exported from calling
  hotplug scripts
- fixed cases in which we try to obtain a HWDESC for an INTERFACE
- fixed caching of HWDESC <-> INTERFACE relations. Cache them also
  if HWDESC was determined via get_hwdesc()
- avoid a loop in ifup calling itself recursively: Check if iface
  is really available before callinig ifup
- remove cached HWDESC <-> INTERFACE relations when ifdown was
  called from hotplug
- Only use interface alias name as label if no LABEL was set.
* Fri Sep  5 2003 poeml@suse.de
- dhcpcd-hook: fix the broken debug message "new IP address: )" as
  described in [#29945]
* Wed Sep  3 2003 mmj@suse.de
- Only move the temporary files if they are there [#29936]
* Mon Sep  1 2003 mmj@suse.de
- Make it version 0.23.30
* Mon Sep  1 2003 zoz@suse.de
- Changes in /etc/sysconfig/network/scripts/functions:
  + functions *_cached_config_data() now have a additional
    optional argument to set the file prefix (up to now always
    'if-'). Needed to cache not only CONFIG <-> INTERFACE
    releations but also HWDESC <-> INTERAFACE relations when no
    matching configuration could be found. This information will
    be used later with 'rcnetwork restart' if a configuration for
    that HW was created in meantime.
  + made functions {write,delete}_cached_config_data() more
    robust by using a temporary file.
  + write_cached_config_data() does not longer write lines with
    empty values
  + delete_from_cached_config_data() removes new empty files
    immediately.
  + added function grep_cached_hwdesc_data() to get all HWDESC
    <-> INTERFACE relations where HWDESC contains CONFIG.
  + added new functions for determining a hardware description
    from an interface name using ethtool and /var/lib/pcmcia/stab:
    ask_ethtool, grep_pcmcia_stab and get_pcmcia_slot() are just
    helper functions for get_hwdesc().
- Changes in /sbin/ifup:
  + fixed some comments
  + Use cached CONFIG only if ifup was called with one argument
    (<config>) and if this <config> seems to be an interface name.
  + cache HWDESC <-> INTERFACE relation if no CONFIG was found.
    Only when ifup and if option 'hotplug' was used.
  + Don't set INTERFACE=rc_manual if it already was a available
    interface.  + Search for HWDESC <-> INTERFACE relations if no
    interface was found for an existing CONFIG. Call ifup again
    with all matching HWDESC INTERFACE pairs.
  + delete cached HWDESC <-> INTERFACE relation if there finaly
    is a valid CONFIG <-> INTERFACE relation.
  + Always cache CONFIG <-> INTERFACE releations, even if called
    from rcnetwork.
  + try to get a hardware description with get_hwdesc() if no
    CONFIG <-> HWDESC relation was cached and if option 'hotplug'
    was used.
* Fri Aug 29 2003 poeml@suse.de
- Fix a warning message issued by the dhcpcd-hook script [#29581]
  when being called without a leaseinfo file specified. This
  happened when a DHCP lease had never acquired before, like during
  the installation, so such a file had not been created. (poeml)
- ifup: added setting of MTU for 6to4 tunnel interfaces (zoz)
- ifup: Fixed some error messages and a typo (zoz)
- non functional change in scripts/functions and rcnetwork:
  - RUN_FILES_BASE now contains only the path (/var/run/sysconfig)
    and no longer the filename prefix 'if-'. Filename prefixes are
    added where $RUN_FILES_BASE is used. (zoz)
* Wed Aug 27 2003 mmj@suse.de
- Updates from jg:
  o Set default for variable WIRELESS back to "" from "no"
  o Exiting without error now in case we do not have the apropriate
    tools and WIRELESS is not set to "yes" [#29323]
* Mon Aug 25 2003 poeml@suse.de
- add the /etc/sysconfig/network/scripts/dhcpcd-hook script that is
  run by the dhcpcd DHCP client upon interface configuration
  (up/down/new address). dhcpcd-hook in turn runs 'ifup <interface>
  - o dhcp'. Comment in sysconfig.dhcp-network adjusted.
- make waiting time for dhcp client on bootup configurable [#27780]
- add documentation about the DHCLIENT_PRIMARY_DEVICE variable,
  and documentation about running multiple DHCP clients
- add hint about DHCLIENT_CLIENT_ID to the documentation of the
  DHCP sysconfig template
- add activation metadata to the sysconfig templates [#28960]
* Mon Aug 25 2003 mmj@suse.de
- Update to version 0.23.29:
  · code to set up interface bonding
  · fix ifup-wireless error message
  · Added hook to is_iface_available();
  · Set MTU _after_ interface link is up
  · Avoid duplicate forwarders in named.conf [#28459]
  · Move /etc/sysconfig/* directories to filesystem package
  · Added auto-detection for wlan devices
  · Get rid of /var/lib/firewall (old personal-firewall cruft) [#28795]
  · Support for tunnel of different type: ipip, gre, sit and 6to4
  · Improved messages for rcnetwork if multiple adresses are configured
  · New option "dhcp" to if* and if*-route:
  - if* will no longer call POST_UP and PRE_DOWN scripts if
    not called with '-o dhcp' (PRE_UP and POST_DOWN are still
    called)
  - if* will call POST_UP and PRE_DOWN script and if*-route if
    called with '-o··· dhcp'
  - if*-route will not read /etc/sysconfig/network/routes if
    called with '-o    dhcp'. Only ifroute-* will be used.
    (dhcp client will call 'if* <interface> -o dhcp' when it
    got/lost/renewed a lease. So POST_UP will be executed after
    the interface is really up and configured.)
  · Other small fixes and formatting changes
* Tue Aug 12 2003 poeml@suse.de
- 'rcnetwork status' was, when using ISC dhclient, showing the wron
  lease from /var/lib/dhcp/dhclient.leases. It showed the first one,
  but since the leases file is written like a log, the most current
  lease can be found at the end. Fix this with a patch by Thomas
  Moschny from University of Karlsruhe. [#26566]
- ifup-802.1q: The vconfig tool lives in /usr/sbin, not /sbin, and
  the previous fix for this was not complete [#26430]
- fold in Thorsten's change from Jun 11 2003
* Fri Jul 25 2003 arvin@suse.de
- use absolute path for runlevel in poll.tcpip
* Wed Jun 11 2003 kukuk@suse.de
- Move /etc/sysconfig/* directories to filesystem package
* Fri May  9 2003 mmj@suse.de
- Ensure correct ordering of the devices [#26432]
* Tue Apr  1 2003 mmj@suse.de
- 0.23.28:
  · Fold in 8.2 patches
  · It's /usr/sbin/vconfig not /sbin/vconfig
  · Fix ifup man-page FILES section
  · It's STARTMODE not BOOTMODE
* Tue Mar 11 2003 mmj@suse.de
- Add nullglob fix from zoz [#24917]
* Tue Mar 11 2003 mmj@suse.de
- If there's not IP-address like in the case with DHCP the
  oldnet2new.sh script did not write a configuration file at all.
  Moved the check for $IPADDR to fix that [#25060]
* Mon Mar 10 2003 ro@suse.de
- call insserv with -f if needed
* Mon Mar 10 2003 mmj@suse.de
- Don't make symlink for pcmcia [#24925]
* Tue Feb 25 2003 zoz@suse.de
- Fixed bug in ifup: read_cached_config_data() returned empty
  string to INTERFACE and this must not be [#23830]
* Fri Feb 21 2003 mmj@suse.de
- Add nullglob to avoid errormessages [#23798]
* Thu Feb 20 2003 poeml@suse.de
- 0.23.27:
  - add meaningful exit codes to /sbin/ifstatus-dhcp (cf. bug
    [#23593]). Before, a call to 'rcnetwork status' would get always
    0 from it, so DHCP interfaces were always "running".
  - sysconfig.dhcp-network: change default of
    DHCLIENT_MODIFY_NIS_CONF to "yes" (cf. bug #23734). The
    reasoning is that the default of DHCLIENT_SET_DOMAINNAME is
    "yes" and it does not make sense if only one of them is active.
* Mon Feb 17 2003 mmj@suse.de
- Up to 0.23.26 - mostly changes by arvin and zoz
  · functions, ifup - Changed handling runtime information in
    /var/run/sysconfig/if-* to store more info for ppp
  · Removed misleading comment about automatic detection of WLAN
    hardware [#20431]
  · Inform smpppd if we were called via rcnetwork.
* Tue Feb 11 2003 mmj@suse.de
- Add a script to drop the extraneous eth-pcmcia symlink
* Thu Feb  6 2003 mmj@suse.de
- Make metadata correct [#23343]
* Wed Jan 22 2003 poeml@suse.de
- 0.23.25
- rcnetwork: add a restart-all-dhcp-clients action.
- ifup-dhcp:
  - find stale pid files and delete them
  - wait until a dhcpcd process is really gone, otherwise an
    'rcnetwork restart' can fail with "dhcpcd already running"
- modify_resolvconf man page: fix synopsis (-p is not optional)
- ifup-ppp: fixed status infos (arvin)
* Thu Jan  9 2003 mmj@suse.de
- Fix ip link list on aliases. [#22826]
* Wed Jan  8 2003 mmj@suse.de
- Add more sysconfig metadata
* Mon Jan  6 2003 msvec@suse.cz
- better debugging functions
- clean up some superfluous messages
- decreased ifstatus verbosity if run from rcnetwork
- unified man pages
* Tue Dec 10 2002 mmj@suse.de
- Added sysconfig metadata
* Fri Nov 15 2002 arvin@suse.de
- adapted ifup-ppp to new smpppd concept (use one daemon per
  interface)
* Fri Nov  1 2002 mmj@suse.de
- Cleaned up documentation with regards to old not used IPv6
  variables
* Thu Oct 24 2002 mmj@suse.de
- Add the IPv6 patch from Olaf Kirch and bump version to 0.23.24
* Mon Oct 14 2002 arvin@suse.de
- ifup-ppp adapted to move of cinternet from /usr/sbin to
  /usr/bin (bug #20841)
* Wed Sep 18 2002 mmj@suse.de
- Up to 0.23.23: merge all pending patches and re-add README
* Mon Sep 16 2002 arvin@suse.de
- fixed update of dsl configuration from 7.3 and older
  distributions (bug #19685)
* Tue Sep 10 2002 poeml@suse.de
- fix an irritating error message in when setting up point-to-point
  devices.
  To print out the netmask (for other devices) the netmask is
  converted from the prefix length if needed. This used shell
  function (mask2pfxlen) leads to an ugly error message when called
  without argument.
- fix a wrong usage of "exit" instead of "return" in the other one
  of the netmask<->prefix conversion functions (mask2pfxlen). No
  known breakage so far, but in cases with misconfigured device
  configuration files (missing prefix/netmask) it is likely that
  ifup fails because the script is quit. [#19332]
* Mon Sep  9 2002 ro@suse.de
- leave FIREWALL off by default
* Mon Sep  9 2002 mmj@suse.de
- Add functionality to start the SuSEfirewall2 when interfaces
  are brought up. [#18840]
* Sat Sep  7 2002 poeml@suse.de
- fix quoting in last change
* Fri Sep  6 2002 mmj@suse.de
- Use /bin/awk instead of /usr/bin/tr [#19051]
* Fri Sep  6 2002 msvec@suse.cz
- split and enhanced documentation
- removed obsolete, useless and empty files
- 0.23.22
* Thu Sep  5 2002 mmj@suse.de
- Don't modprobe in ifup-wireless. From zoz. [#18755]
* Mon Sep  2 2002 mmj@suse.de
- Fix typo in specfile, and therefore start network pr. default.
* Fri Aug 30 2002 poeml@suse.de
- 0.23.21
- Before the rcnetwork<->ifup interface was cleaned up recently,
  ifstatus <device> returned quite some output when not called
  manually (not from rcnetwork). I added a function
  message_if_not_run_from_rc to be used in those cases where the
  behaviour shall depend on RUN_FROM_RC or not, restoring the old
  behaviour. See bug #18628. (poeml)
- Fix bug #18156: If rcnetwork is called as ./network from
  /etc/init.d, it bites us that we change dir to
  /etc/sysconfig/network always.  Executing $0 doesn't work
  therefore (used in "restart" et al.). So let's change to $OLDPWD
  in these cases to make it work. (poeml)
* Thu Aug 29 2002 mmj@suse.de
- Fixes from zoz:
  o INTERFACETYPE was wrong for ifaces with two
    digit numbers. Fixes [#18074] and [#18524]
  o Changed return value for 'status' [#17764]
* Tue Aug 27 2002 mmj@suse.de
- Do not mention /etc/sysconfig/firewall but instead mention
  /etc/sysconfig/SuSEfirewall2. [#18277]
* Mon Aug 19 2002 mmj@suse.de
- kkeil fixed ip-up.d references the places I forgot.
* Mon Aug 19 2002 mmj@suse.de
- /etc/ppp/if-{up,down}.d -> /etc/ppp/ip-{up,down}.d
* Mon Aug 19 2002 poeml@suse.de
- scripts/network: - make 'rcnetwork ... -o quiet' work. So far,
  this option was not effective even though the documentation
  promised it. In fact, ifup and friends were always called with
  option "quiet", while now they get this option only   when it was
  given as argument to rcnetwork (BE_QUIET is unset otherwise).
- print messages only if "quiet" option was not given (using
  debug() instead of message() for info message)
- output of data during configuration:
  - add message_n() function, equivalent to echo -n
  - add pfxlen2mask() function to convert a prefix length to a
    netmask. This allows ifup to print the NETMASK even if only the
    prefix length might be given in the config files.
- so far, an ifcfg-123456abcdef file (MAC-address specific
  configuration) had to be named in lower case letters.  Now it can
  be upper case, too (which allows copy and paste from ifconfig
  output).
- as the documentation mentions the STARTMODE "[on]boot", "boot" is
  now also   recognized.
- ignore configurations with STARTMODE=off|ignore (--> returning
  R_NOTCONFIGURED)
- remove the (new and never used) DHCLIENT_RESTART_SERVICES hook --
  this is better handled by dhcpd-*.exe, or by ip-up.d/*
- make 'rcnetwork restart -o ...' work. So far, options would have
  been interpreted as interface names by the called scripts.
- replaced mask2pfxlen() function with a 30%% faster version
- don't handle the YP domainname -- it's taken care of in aaa_base
* Sun Aug 18 2002 poeml@suse.de
- more oldnet2new.sh changes:
  o convert an unlimited number of interfaces, not only _0 _1 _2 _3
  o remove up to 32 instances of IPADDR_, NETDEV_, and IFCONFIG_
    variables from rc.config
  o read mtu from old config and write it as MTU= to ifcfg files
  o Handle YP domainname just in case it's not handled somewhere
    else
  o always source rc.config if present
- ifup-dhcp:
  o if a pid file for an interface exists but no corresponding
  process is running, delete it to allow dhcpcd to start [#16819]
  o increase waiting time for an address to 15
  o print NETMASK and HOSTNAME in addition to the IP address
  o DHCLIENT_HOSTNAME_OPTION: AUTO may be upper or lower case
  o add two new hooks: DHCLIENT_RESTART_SERVICES and DHCLIENT_SCRIPT_EXE
- allow to use MTU and LLADDR as options when setting up a link
- fix USEPEERDNS for ISDN (#17574)
- show IP address and netmask/peer when upping a device, except lo
- extend PreReqs to textutils, fileutils, gawk, /usr/bin/sed
- version 0.23.20
* Fri Aug 16 2002 bk@suse.de
- oldnet2new.sh changes:
  o fix S/390 pointopoint interfaces ctc, escon, iucv and ci:
  - move code shared with ippp/isdn to parse_ifconfig() and
    initialize NETMASK$I in the function head before converting
  o source rc.config if not called with rc.config env by YaST2
  o don't use empty NETMASK and BROADCAST variables
  o remove broken NETWORK variable
  o always put BOOT_MODE at the end
  o remove use of cat to avoid needing textutils
- add sed and fileutils to PreReqs.
* Mon Aug 12 2002 mmj@suse.de
- Added comments to the wireless stuff [#17474]
* Fri Aug  9 2002 mmj@suse.de
- Fix breakage of one to many %%dir added before
* Fri Aug  9 2002 mmj@suse.de
- Folded in ip-{up,down} and poll.tcpip from aaa_base
- Added directories /etc/ppp/if-{up,down}.d, and support for exe-
  cuting scripts in there [#17534].
* Wed Aug  7 2002 mmj@suse.de
- Added support for /etc/sysconfig/network/if-{up,down}.d dirs for
  scripts to be executed on up and down of interfaces. [#17463]
  Thanks to Andreas Hasenack <andreas@conectiva.com.br>
* Tue Aug  6 2002 ihno@suse.de
- New Parameter WAIT_FOR_INTERFACES to wait for interfaces to be
  configured. Default is nowait (empty value)
* Fri Aug  2 2002 poeml@suse.de
- package Olaf's ifup-802.1q
* Wed Jul 31 2002 mmj@suse.de
- Add PreReq: for fillup_and_insserv
* Thu Jul 25 2002 mmj@suse.de
- Fixed rcnetwork restart <dev> [#17107]
* Wed Jul 24 2002 arvin@suse.de
- fixed selection of provider in ifup-ppp (bug #17167)
* Wed Jul 24 2002 schwab@suse.de
- Fix syntax in oldnet2new script.
- Fix configure script and use autoreconf.
* Tue Jul 23 2002 mmj@suse.de
- Added the insserv call for network.
* Wed Jul 17 2002 mmj@suse.de
- Added vlan support from Olaf Kich <okir@suse.de>
* Wed Jul 10 2002 mmj@suse.de
- Show the startmode rather than 'skipped'
* Tue Jul  9 2002 arvin@suse.de
- fixed parsing of /etc/sysconfig/network/config in
  modify_resolvconf script
* Mon Jul  8 2002 mmj@suse.de
- Start network in runlevel 2 pr. default.
* Mon Jul  8 2002 mmj@suse.de
- New sysconfig package to sync with CVS
* Mon Apr 15 2002 arvin@suse.de
- fixed boot order (dsl is now started after eth) (bug #15783)
* Fri Mar 22 2002 kkeil@suse.de
- update old rc.config settings for ippp* and isdn* devices
* Fri Mar 22 2002 mmj@suse.de
- This package should not own /etc/sysconfig but should own
  /etc/sysconfig/scripts
* Thu Mar 21 2002 kkeil@suse.de
- set have to use set -- $... to set positional parameters (#15271)
* Tue Mar 19 2002 mmj@suse.de
- Change R_INTERNAL to return 1 instead of the not-allowed 12. One
  is specified as "FAIL : 1 - generic or unspecified error"
  Fixes (Bug #15078)
* Mon Mar 18 2002 mmj@suse.de
- Make rcnetwork fail nicely on wrong option (Bug #15111)
* Thu Mar 14 2002 arvin@suse.de
- check for presents of modem0 in wvdial.conf before generating
  ifcfg-ppp0 during update
* Tue Mar 12 2002 mmj@suse.de
- ifup-route:
  - removed determination of INTERFACETYPE; it was never used
  - treat 5th column in routes and ifroute-* like the first four
    and allow a dash if the type is omitted.
- config:
  - removed NO_ROUTING_INTERFACETYPES, because it was not used
    anywhere
- manpages update
- network:
  - don't drop configuration files which are symlinks when called
    manually.
  - 'rcnetwork status': accept returnvalue R_BUSY as success;
    ifup-ippp returns R_BUSY if the interface is connected.
    (Bug #14858)
- ifup-dhcp, sysconfig.dhcp-network
  - add DHCLIENT_SLEEP again, for the real broken devices
- ifup
  - add missing \ in line 400 (Bug #14823)
- oldnet2new.sh
  - Don't make PCMCIA link if it exists
- ifup-ppp
  - added tiny sleep to avoid race condition
* Fri Mar  8 2002 mmj@suse.de
- Always DHCLIENT_SET_DOWN_LINK=yes for pcmcia ifaces.
* Thu Mar  7 2002 mmj@suse.de
- Don't save interface names for ppp and dsl ifaces (Bug #14497)
- Add ifcfg.template
- Fix the %%post way of calling oldnet2new.sh
- Convert MODIFY_RESOLV_CONF_DYNAMICALLY and CLOSE_CONNECTION
  correctly (Bug #14600)
* Wed Mar  6 2002 arvin@suse.de
- fixed converting of modem and dsl config during update
* Wed Mar  6 2002 mmj@suse.de
- Renamed variables for if*-connection and added an option to have
  verbose output from ifstatus without changing functionality
- rcnetwork should not kill all interfaces if option type is used
- Reduce output of 'rcnetwork' (Bug #14496)
* Tue Mar  5 2002 ro@suse.de
- corrected postinstall-script
* Tue Mar  5 2002 arvin@suse.de
- fixed return values of ifup-ppp script
* Mon Mar  4 2002 mmj@suse.de
- Convert PCMCIA configs during update.
* Mon Mar  4 2002 arvin@suse.de
- convert modem and dsl config during update (bug #14330)
* Mon Mar  4 2002 mmj@suse.de
- 0.23.14
- /usr/bin/logger -> /bin/logger
- made rc.status aware of the current ACTION. Now it writes the
  right strings for a given error value (Bug #14061)
- fixed garbled output for rcnetwork status
- added a INFO to start and stop if any interface was skipped.
- Default CHECK_DUPLICATE_IP to 'no' (Bug #14280)
- while trying to get the right configuration file we always used
  the interfacetype derived from the interface argument (if
  available). So we could never call something
  like 'ifup eth-pcmcia tr0'.  Now we use the interfacetype
  derived from the interface argument only if there was no
  interfacetype in the config string.
- check STARTMODE not only for ifup, but also for ifstatus. One
  would hardly call ifstatus with -o hotplug or -o onboot, but on
  the other side with this change we will get interface
  information for hotplug interfaces from temporary files and can
  report their status too.
- ignore errors when shutting down an iface (in detail errors
  from 'ip address del/flush' and 'ip link set down'). I only got
  errors at these lines when calling that for an already
  unplugged hotplug device.  (Remember: we must call ifdown even
  for already unplugged devices, to clean up things like modified
  default routes or temporary interface information in
  /var/run/syslog/if-*)
* Thu Feb 28 2002 mmj@suse.de
- Only put the UNIQUE information in the netconffile if not
  already present
* Tue Feb 26 2002 mmj@suse.de
- Add option to /etc/init.d/network to allow only certain inter-
  face types to be started (rcnetwork <action> -o type=isdn,ippp)
- lo was still set down: fixed (it happened in the 'stop anything
  that is still alive' section after the main stopping loop)
- don't do any special if* calls when config is given as second
  argument
- added some options: [on]boot, hotplug, check, quiet, debug (like
  ifup)
- added option fake: don't call if*; instead print commands to
  stdout
- added option type=<comma sepearted list of iface types> to act
  only on that types of interfaces
* Tue Feb 26 2002 mmj@suse.de
- version 0.23.13
- first use SIGTERM then SIGKILL, but only when KILL_CONNECTIONS is
  set.
- use ifuser again. Without it we would kill all connections/nfs
  mounts not only these of current iface
- improved output of ifstatus-connection
- added option check for ifstatus: it then returns R_BUSY (10) if
  there are open connections or nfs mounts (needed for pcmcia)
- return retval from 'ifup alias' calls
- It's not noarch anymore
* Tue Feb 26 2002 mmj@suse.de
- version 0.23.12
- ifdown-connection: - dont check if available or up, because there
  might be connections of already unplugged devices which are
  neither available nor up.
- fixed message in check section
- functions: - if ifdown-* is called with -o hotplug, then
  is_iface_available() returns always 0.
- add option UMOUNT_NFS_WHEN_IFDOWN and comment out ifuser call
  in nfs_check()
* Fri Feb 22 2002 mmj@suse.de
- version 0.23.11
- Make ifup more verbose about duplicate IP's
- is_iface_available returns 0 for ppp* and dsl*
- fixed wrong case for $ACTION in main loop - don't set up default
  route for noiface, lo, dummy
- merged 'add|replace' and 'status' loops to one loop and branch to
  this two cases in the middle of the loop.  There were too much
  common code in these two loops.
- STARTMODE mismatch is not longer logged as an error but as
  message - fixed error when -o doalias but there were no alias
  configs - tweaked CHECK_DUPLICATE error message again
* Wed Feb 20 2002 kkeil@suse.de
- fix return value for isdn interface check
* Mon Feb 18 2002 poeml@suse.de
- version 0.23.10:
- ifcfg-*: variable BOOTMODE is now called STARTMODE (fits better).
  Values are onboot, hotplug, or manual. Assume 'manual' when unset.
- rcnetwork: stop _all_ active devices and kill _all_ DHCP clients
  (not only the configured ones)
- try to bind routes to an interface
- is_iface_available considers ippp* and isdn* devices as always
  available
- ifup-route: add a link named ifstatus-route
* Mon Feb 18 2002 mmj@suse.de
- Don't do any unique.inf stuff is it is not present ...
- ifdown-dhcp all will kill all dhcp clients
- change screen output of rcnetwork start, stop, status
* Mon Feb 18 2002 mmj@suse.de
- Added a manpage for routes
* Mon Feb 18 2002 mmj@suse.de
- Moved ppp and dsl scripts from /sbin to the correct place.
- Added functionality to convert old YaST.inf unique information
  to UNIQUE=
* Mon Feb 18 2002 poeml@suse.de
- version 0.23.9:
  - add directory /var/run/sysconfig/
  - rcnetwork:
  - fix usage of rc_status (always showed "done")
  - print MESSAGE before the next script gets started
  - ifdown-dhcp:
  - don't rely on a pid file when looking for clients to kill.
  - Make script output depending on whether called by rc script
    or not.
  - config/sysconfig.dhcp-network: 5 is now the default
    RebootTimeOut
  - oldnet2new.sh: take the chance and convert obsolete iSeries
    device names... veth --> eth (#12583)
* Fri Feb 15 2002 poeml@suse.de
- version 0.23.8:
  - never stop loopback device when calling rcnetwork directly
  - added variable RUN_FILES_BASE for dynamic configuration of ifup
  - ifup: changed BOOTMODE checking, added IP_OPTIONS
  - scripts/network: changed removal of route stack run-time-files
  - is_iface_available(): It will now only modprobe <interface> if
    called from ifup, because it must not trigger unwanted
    hotplug events (#13178, dhcpcd was started twice)
  - ifup-dhcp and sysconfig.dhcp:
  - add DHCLIENT_REBOOT_TIMEOUT (time that dhcpcd will try to
    reacquire a previous lease
  - DHCLIENT_HOSTNAME_OPTION defaults to "AUTO", reads /etc/HOSTNAME
  - add DHCLIENT_LEASE_TIME and DHCLIENT_ADDITIONAL_OPTIONS (#13211)
  - detect whether dhcpcd is already running on the given device
  - unified option handling and return values
* Mon Feb 11 2002 poeml@suse.de
- new version 0.23.7:
  - make dhcpcd work with multiple interfaces
    (DHCLIENT_PRIMARY_INTERFACE can be set in ifcfg-*; otherwise
    the first device is primary)
  - add DHCP config variables for NIS, NTP, vendor class ID,
    default gateway configuration and DHCLIENT_BIN
  - send hostname option by default (needed for DDNS)
  - move ifdown-connection and ifup-{route,wireless} (and their
    links) from /sbin to /etc/sysconfig/scripts/
* Tue Feb  5 2002 mmj@suse.de
- Small tweaks, update to 0.23.6
* Tue Feb  5 2002 mmj@suse.de
- Lots of script updates, version 0.23.5
* Tue Feb  5 2002 poeml@suse.de
- autoconfiscated, version 0.23.4
* Mon Feb  4 2002 poeml@suse.de
- update ifup-dhcp
- add link /sbin/ifstatus-dhcp -> ifup-dhcp
- add modify_resolvconf and man page (moved from aaa_base package)
- add MODIFY_RESOLV_CONF_DYNAMICALLY to config
- don't copy ifup-ppp to ifup-dsl, link it
- add ifdown-wireless link
- fix permisisons of almost everything
* Mon Feb  4 2002 arvin@suse.de
- fixed links for ppp and dsl
* Mon Feb  4 2002 mmj@suse.de
- ifup-wireless and ifdown-connection added in addition to update
  to the most current version of everything.
* Thu Jan 31 2002 mmj@suse.de
- dhcp updates
* Wed Jan 30 2002 mmj@suse.de
- Use a proper version number
* Mon Jan 28 2002 mmj@suse.de
- Added /etc/sysconfig/network/providers
* Mon Jan 28 2002 mmj@suse.de
- Updated to newest scripts.
* Fri Jan 25 2002 poeml@suse.de
- Add conveniance wrapper rcdhclient, telling to use the new scripts
* Fri Jan 25 2002 arvin@suse.de
- added ppp and dsl support
* Wed Jan 23 2002 mmj@suse.de
- Added symlink to ifdown-dhcp
* Wed Jan 23 2002 mmj@suse.de
- Added ifup.1
- Fixed a typo in README
- Made usage() more fine-grained in ifup
- Fixed missing %%files entry for /etc/sysconfig/network/config
* Mon Jan 21 2002 mmj@suse.de
- Updated config, functions, ifstatus-route, ifup ifup-dhcp,
  ifup-route and network
* Sat Jan 19 2002 mmj@suse.de
- Updated ifup, ifup-route, functions, network, config
* Wed Jan 16 2002 ro@suse.de
- added insserv calls
- fixed provides/requires of network script
* Wed Jan 16 2002 mmj@suse.de
- Added routing conf conversion
* Wed Jan 16 2002 mmj@suse.de
- Add missing rcnetwork -> /etc/init.d/network link
* Tue Jan 15 2002 mmj@suse.de
- Fixed permissions and added a symlink from ifup-route ->
  ifdown-route
* Tue Jan 15 2002 mmj@suse.de
- Fixed bugs and added hostname conversion
* Wed Nov 21 2001 mmj@suse.de
- Initial package
